%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          Computes inivariate LM tests for autoregressive       %
%          conditional heteroskedasticity                        %
%                                                                %
%          Function: arch                                        %
%                                                                %
%          Input:                                                %
%                       epsilon: nxT matrix with residuals       %
%                       freq: data frequency                     %
%                       t: degrees of freedom from original      %
%                           estimates                            %
%                                                                %
%          Output:                                               %
%          	            results: matrix with results             %
%                       df: matrix with degrees of freedom       %
%                                                                %
%          This version:        June 1, 2004                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [results,df] = arch(epsilon,freq,t)

[n T] = size(epsilon);
y = epsilon(:,2:T).*epsilon(:,2:T);
y1 = epsilon(:,1:T-1).*epsilon(:,1:T-1);
results = zeros(n,2);

curr_ini = find_inisettings;

%
% create matrices for 1 year lag
%

if strcmp(freq,'')==0;
   if strcmp(freq,'q')==1;
      k = 4;
   else;
      k = 12;
   end;
   yk = epsilon(:,k+1:T).*epsilon(:,k+1:T);
   yk1 = epsilon(:,k:T-1).*epsilon(:,k:T-1);
   for i=2:k;
      yk1 = [yk1;epsilon(:,k+1-i:T-i).*epsilon(:,k+1-i:T-i)];
   end;
else;
   k = 1;
end;

%
% Setting up the default df matrix
%

if curr_ini.sscorrect==0;
   if k==1;
      df = zeros(n,1);
   else;
      df = zeros(n,2);
   end;
else;
   if k==1;
      df = zeros(n,2);
   else;
      df = zeros(n,4);
   end;
end;

for i=1:n;
   x = y(i,:);
   x1 = y1(i,:);
   x1 = [ones(1,size(x1,2));x1];
   b = (x*x1')/(x1*x1');
   eps1 = x-b*x1;
   x = x-(1/(T-1))*sum(x);
   LM = (T-1)*(1-((eps1*eps1')/(x*x')));
   if curr_ini.sscorrect==1;
      LM = ((t-2)/(T-1))*LM;
      results(i,1) = LM;
      df(i,1) = 1;
      df(i,2) = (t-2);
   else;
      results(i,1) = LM;
      df(i,1) = 1;
   end;
   if k>1;
      x = yk(i,:);
      x1 = yk1(i,:);
      for j=2:k;
         x1 = [x1;yk1(i+(j-1)*n,:)];
      end;
      x1 = [ones(1,size(x1,2));x1];
      b = (x*x1')/(x1*x1');
      eps1 = x-b*x1;
      x = x-(1/(T-k))*sum(x);
      LM = (T-k)*(1-((eps1*eps1')/(x*x')));
      if curr_ini.sscorrect==1;
         LM = ((t-k-1)/((T-k)*k))*LM;
         results(i,2) = LM;
         df(i,3) = k;
         df(i,4) = (t-k-1);
      else;
         results(i,2) = LM;
         df(i,2) = k;
      end;
   end;
end;

if curr_ini.sscorrect==0;
   pval = chis_cdf(results(:,1),df(:,1));
   results = [results (1-pval)];
   if k>1;
      pval = chis_cdf(results(:,2),df(:,2));
      results = [results (1-pval)];
   end;
else;
   pval = fdis_cdf(results(:,1),df(:,1),df(:,2));
   results = [results (1-pval)];
   if k>1;
      pval = fdis_cdf(results(:,2),df(:,3),df(:,4));
      results = [results (1-pval)];
   end;
end;

%
% end of arch.m
%
