%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI box                                        %
%                                                                %
%          Function: axesbox                                     %
%                                                                %
%          Input:                                                %
%                       boxvec: 1x4 vector with left, bottom,    %
%          		          width, and height                        %
%                       title: Text string for box               %
%                       titlewidth: width of title string        %
%                       mycolors: 1x2 or 1x4 vector with dark    %
%                          and light color values (0 -> 1)       %
%                       visibility: text string (default is on)  %
%                       cu_ini: structure with ini settings      %
%                                                                %
%          Output:                                               %
%          		          axes box control                         %
%                                                                %
%          This version:        April 4, 2006                    %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function boxhandle = axesbox(boxvec,title,titlewidth,mycolors,visibility,cu_ini)

left = boxvec(1,1);
bottom = boxvec(1,2);
width = boxvec(1,3);
height = boxvec(1,4);

if nargin<=3;
   dark = 0.5;
   light = 1;
   dark2 = dark;
   light2 = light;
else;
   dark = mycolors(1,1);
   light = mycolors(1,2);
   if size(mycolors,2)==4;
      dark2 = mycolors(1,3);
      light2 = mycolors(1,4);
   else;
      dark2 = dark;
      light2 = light;
   end;
end;

if nargin<=4;
   visibility = 'on';
end;

if nargin<=5;
   cu_ini = find_inisettings;
end;

lightvec = [light light light];
darkvec = [dark dark dark];
lightvec2 = [light2 light2 light2];
darkvec2 = [dark2 dark2 dark2];

if size(mycolors,2)==2;
   if isalmostequal(darkvec,cu_ini.frame_shade_color)==0;
      darkvec = cu_ini.frame_shade_color;
      darkvec2 = darkvec;
   end;
   if isalmostequal(lightvec,cu_ini.frame_light_color)==0;
      lightvec = cu_ini.frame_light_color;
      lightvec2 = lightvec;
   end;
else;
   if isalmostequal(darkvec,cu_ini.gui_shade_color)==0;
      darkvec = cu_ini.gui_shade_color;
   end;
   if isalmostequal(lightvec,cu_ini.gui_dark_color)==0;
      lightvec = cu_ini.gui_dark_color;
   end;
   if isalmostequal(lightvec2,cu_ini.gui_light_color)==0;
      lightvec2 = cu_ini.gui_light_color;
   end;
end;

fixed = 0;
if matlabnumber>=6.0;
   fixed = 1;
end;

%
% setting up the axes
%

% the bottom x axis

h1 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left+1 bottom width 1], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',lightvec2, ...
   'YColor',lightvec2, ...
   'ZColor',lightvec2);

h2 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left bottom+1 width-1 1], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',darkvec2, ...
   'YColor',darkvec2, ...
   'ZColor',darkvec2);

% the left y axis

h3 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left bottom+1 1 height-1], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',darkvec, ...
   'YColor',darkvec, ...
   'ZColor',darkvec);

h4 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left+1 bottom+2 1 height-2], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',lightvec, ...
   'YColor',lightvec, ...
   'ZColor',lightvec);

% the top x axis

h5 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left+1 bottom+height-1 width-2 1], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',lightvec, ...
   'YColor',lightvec, ...
   'ZColor',lightvec);

h6 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left bottom+height width-1 1], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',darkvec, ...
   'YColor',darkvec, ...
   'ZColor',darkvec);

if matlabnumber>=6.0;
   h9 = axes('Units','pixels', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[left bottom+height+1 1 1], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','frame', ...
      'Visible',visibility, ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));
end;

% the right y axis

h7 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left+width-1 bottom+1 1 height-fixed], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',darkvec2, ...
   'YColor',darkvec2, ...
   'ZColor',darkvec2);

h8 = axes('Units','pixels', ...
   'TickLength',[0 0], ...
   'CameraUpVector',[0 1 0], ...
   'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
   'Position',[left+width bottom 1 height-fixed], ...
   'XTickLabelMode','manual', ...
   'YTickLabelMode','manual', ...
   'Tag','frame', ...
   'Visible',visibility, ...
   'XColor',lightvec2, ...
   'YColor',lightvec2, ...
   'ZColor',lightvec2);

if matlabnumber>=6.0;
   h10 = axes('Units','pixels', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[left+width+1 bottom-1 1 1], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','frame', ...
      'Visible',visibility, ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));
end;

if titlewidth>0;
   h11 = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[left+10 bottom+height-8 titlewidth 15], ...
      'ForegroundColor',cu_ini.frame_color, ...
      'FontSize',cu_ini.gui_fontsize, ...
      'FontName',cu_ini.gui_fontname, ...
      'FontWeight',cu_ini.gui_fontweight, ...
      'FontAngle',cu_ini.gui_fontangle, ...
      'Style','text', ...
      'UserData',bottom+height-8, ...
      'String',title, ...
      'Visible',visibility, ...
      'Tag','FrameText');
   %
   % fix based on extent property
   %
   txt_extent = get(h11,'Extent');
   set(h11,'Position',[left+10 bottom+height-8+((15-txt_extent(1,4))/2) txt_extent(1,3:4)]);
   if iswinxp==1;
      set(h11,'Position',[left+10 bottom+height-8-(txt_extent(1,4)/4) txt_extent(1,3:4)],'UserData',bottom+height-15.5+(txt_extent(1,4)/4));
   end;
end;

if nargout==1;
   if titlewidth>0;
      if matlabnumber>=6.0;
         boxhandle = [h1 h2 h3 h4 h5 h6 h7 h8 h9 h10 h11];
      else;
         boxhandle = [h1 h2 h3 h4 h5 h6 h7 h8 h11];
      end;
   else;
      if matlabnumber>=6.0;
         boxhandle = [h1 h2 h3 h4 h5 h6 h7 h8 h9 h10];
      else;
         boxhandle = [h1 h2 h3 h4 h5 h6 h7 h8];
      end;
   end;
end;

%
% end of axesbox.m
%
