function [betar,dfbeta,const_rest] = beta_alt_estimate(S_00,S_11,S_01,S_10,beta,T,modelsdir,modelfile,dcoint,q1,d_coint,d_corel,d_coidet)

%
% just estimate beta under linear restrictions.
% the indicator d_coint controls the having been added an
% extra variable to the cointegration space
%

betar = beta;
dfbeta = 0;
const_rest = 0;
r = size(beta,2);
n = size(S_00,1);
nq1 = size(beta,1);
sivec = zeros(r,1);

H = [];
%
% load the normalizations if d_corel is unity
%
if d_corel==1;
   normvec = [];
   file = strcat(modelsdir,'normalize-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.norm');
   if fileexist(file)==1;
      normvec = loaddata(file);
   end;
end;
%
for i=1:r;
   file = strcat(modelsdir,'H_',num2str(i),'-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.rest');
   if fileexist(file)==1;
      h = loaddata(file);
      if d_coint>0;
         h = [h zeros(size(h,1),d_coint);zeros(d_coint,size(h,2)) eye(d_coint)];
      elseif d_corel==1;
         %
         % try to determine which columns of h to remove
         %
         % 1st step is to normalize h such that the row corresponding to
         % the normalizing variable contains exactly 1 in its first element and
         % zeros elsewhere
         %
         if isempty(normvec)==0;
            H_fix = h(normvec(i,1),:);
            j = 1;
            while j<=size(h,1);
              if size(H_fix,1)<size(H_fix,2);
                 if j~=normvec(i,1);
                    H_test = [H_fix;h(j,:)];
                    if rank(H_test)==size(H_test,1);
                       H_fix = H_test;
                    end;
                 end;
                 j = j+1;
              else;
                 j = size(h,1)+1;
              end;
            end;
            h = h/H_fix;
            %
            h1 = h(:,1);
            if size(h,2)>1;
               h2 = h(:,2:size(h,2));
               h = [h1 h2 zeros(size(h2));h1 zeros(size(h2)) h2];
            else;
               h = [h1;h1]
            end;
         else;
            h = [h zeros(size(h));zeros(size(h)) h];
         end;
         if d_coidet==1;
            %
            % check if there's a constant to remove
            %
            keep_rows = (1:1:size(h,1)-1);
            h_ch = h(size(h,1),:);
            keep_cols = 1;
            for i1=2:size(h_ch,2);
               if isequal(h_ch(1,i1),0)==1;
                  keep_cols = [keep_cols;i1];
               else;
                  const_rest = const_rest+1;
               end;
            end;
            h = h(keep_rows,keep_cols);
         end;
      end;
      if i==1;
         bH = h;
      else;
         bH = [[bH zeros(size(bH,1),size(h,2))];[zeros(size(h,1),size(bH,2)) h]];
      end;
      H = [H h];
      sivec(i,1) = size(h,2);
   end;
end;

if min(sivec)>0;
   %
   % Computing input values for beta
   %
   S_bb = beta'*beta;
   %
   % Solving the eigenvalue problem
   %
   % Step 1: Diagonalize S_bb
   %
   [W,rho] = eig(S_bb);
   rho = diag(rho,0);
   [rho2,AscInd] = sort(abs(rho));
   nr = size(AscInd,1);
   DescInd = zeros(nr,1);
   for i=1:nr;
      DescInd(i)=AscInd(nr+1-i);
   end;
   %
   % Resort eigenvalues and eigenvectors
   % in descending order
   %
   rho = rho(DescInd);
   sqrho = sqrt(rho);
   rho = diag(rho,0);
   sqrho = diag(sqrho,0);
   W = W(:,DescInd);
   sqS_bb = (W/(sqrho))*W';
   oldlambda = zeros(r,1);
   for i=1:r;
      %
      % Selecting the restrictions from H
      %
      si = sivec(i,1);
      dfbeta = dfbeta+(nq1-r-si+1);
      sj = size(H,2);
      if i==1;
         Hsel = [eye(si);zeros(sj-si,si)];
      elseif i==r;
         Hsel = [zeros(sj-si,si);eye(si)];
      else;
         sk = sivec(1,1);
         j=2;
         while j<=i-1;
            sk = sk+sivec(j,1);
            j = j+1;
         end;
         Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
      end;
      Hi = H*Hsel;
      %
      % Step 2: Reformulating eigenvalue problem to
      %         calculating the eigenvalues for
      %
      %         adjS_bb = sqS_bb*beta'*Hi*inverse(Hi'*Hi)*Hi'*beta*sqS_bb
      %
      adjS_bb = sqS_bb*beta'*(Hi/(Hi'*Hi))*Hi'*beta*sqS_bb;
      [U,lambdai] = eig(adjS_bb);
      lambdai = diag(lambdai,0);
      [lambdai2,AscInd] = sort(abs(lambdai));
      nr = size(AscInd,1);
      DescInd = zeros(nr,1);
      for i1=1:nr;
         DescInd(i1)=AscInd(nr+1-i1);
      end;
      %
      % Resort eigenvalues and eigenvectors
      % in descending order
      %
      lambdai = lambdai(DescInd);
      U = U(:,DescInd);
      %
      % Renormalize U such that V'S_bbV=I
      %
      V = sqS_bb*U;
      %
      % Computing the initial estimate of betai
      % using the first eigenvector from the
      % solution to the above eigenvalue problem
      %
      betai = beta*V(:,1);
      oldlambda(i,1) = lambdai(1,1);
      if i==1;
         betainit = betai;
      else;
         betainit = [betainit betai];
      end;
   end;
   %
   for i=1:r;
      if oldlambda(i,1)==1;
         oldlambda(i,1) = 0;
      end;
   end;
   betainit = real(betainit);
   if dfbeta>0;
      curr_ini = find_inisettings;
      if curr_ini.convcrit<10;
         ch_convcrit = ['1.0e-00' num2str(curr_ini.convcrit)];
      else;
         ch_convcrit = ['1.0e-0' num2str(curr_ini.convcrit)];
      end;
      ccrit = mystr2num(ch_convcrit);
      %
      % Starting up the iterations
      %
      grad = 1;
      %
      it = 1;
      while ((it<=curr_ini.maxit)&(grad>ccrit));
         newlambda = zeros(r,1);
         for i=1:r;
            %
            % Selecting the restrictions from H
            %
            si = sivec(i,1);
            sj = size(H,2);
            if i==1;
               Hsel = [eye(si);zeros(sj-si,si)];
               tau = betainit(:,2:r);
            elseif i==r;
               Hsel = [zeros(sj-si,si);eye(si)];
               tau = betainit(:,1:r-1);
            else;
               sk = sivec(1,1);
               j=2;
               while j<=i-1;
                  sk = sk+sivec(j,1);
                  j = j+1;
               end;
               Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
               tau = [betainit(:,1:i-1) betainit(:,i+1:r)];
            end;
            Hi = H*Hsel;
            %
            % Computing the S_ij_tau matrices
            %
            S_00_tau = S_00-(S_01*(tau/(tau'*S_11*tau))*tau'*S_10);
            S_11_tau = S_11-(S_11*(tau/(tau'*S_11*tau))*tau'*S_11);
            S_01_tau = S_01-(S_01*(tau/(tau'*S_11*tau))*tau'*S_11);
            S_10_tau = S_10-(S_11*(tau/(tau'*S_11*tau))*tau'*S_10);
            HS_11_tau = Hi'*S_11_tau*Hi;
            %
            % Solving the eigenvalue problem for fixed tau
            %
            % Step 1: Diagonalize HS_11_tau
            %
            [W,rho] = eig(HS_11_tau);
            rho = diag(rho,0);
            [rho2,AscInd] = sort(abs(rho));
            nr = size(AscInd,1);
            DescInd = zeros(nr,1);
            i1 = 1;
            while i1<=nr;
               DescInd(i1)=AscInd(nr+1-i1);
               i1 = i1+1;
            end;
            %
            % Resort eigenvalues and eigenvectors
            % in descending order
            %
            rho = rho(DescInd);
            sqrho = sqrt(rho);
            rho = diag(rho,0);
            sqrho = diag(sqrho,0);
            W = W(:,DescInd);
            %
            % Step 2: Reformulating eigenvalue problem to
            %         calculating the eigenvalues for
            %
            %         adjHS_11_tau =
            %        sqHS_11_tau*Hi'*S_10_tau*inverse(S_00_tau)*S_01_tau*Hi*sqHS_11_tau
            %
            sqHS_11_tau = (W/(sqrho))*W';
            adjHS_11_tau = sqHS_11_tau*Hi'*(S_10_tau/(S_00_tau))*S_01_tau*Hi*sqHS_11_tau;
            [U,lambdai] = eig(adjHS_11_tau);
            lambdai = diag(lambdai,0);
            [lambdai2,AscInd] = sort(abs(lambdai));
            nr = size(AscInd,1);
            DescInd = zeros(nr,1);
            i1 = 1;
            while i1<=nr;
               DescInd(i1)=AscInd(nr+1-i1);
               i1 = i1+1;
            end;
            %
            % Resort eigenvalues and eigenvectors
            % in descending order
            %
            lambdai = lambdai(DescInd);
            U = U(:,DescInd);
            %
            % Renormalize U such that V'HS_11_tauV=I
            %
            V = sqHS_11_tau*U;
            newlambda(i,1) = lambdai(1,1);
            newbetai = Hi*V(:,1);
            %
            % Changing betainit to include newbetai
            % for column i
            %
            check_nan = sum(isnan(newbetai));
            check_imag = sum(imag(newbetai));
            if (isalmostequal(check_nan,0)==0)|(isalmostequal(check_imag,0)==0);
               newbetai = beta(:,i);
            end;
            if i==1;
               betainit = [newbetai betainit(:,2:r)];
            elseif i==r;
               betainit = [betainit(:,1:r-1) newbetai];
            else;
               betainit = [betainit(:,1:i-1) newbetai betainit(:,i+1:r)];
            end;
         end;
         betainit = real(betainit);
         newlambda = real(newlambda);
         %
         % Calculate the convergence criterion using the
         % log-likelihood function
         %
         if curr_ini.betagrad==0;
            oldsum = sum(log(ones(r,1)-oldlambda));
            newsum = sum(log(ones(r,1)-newlambda));
            logdetS_00 = log(det(S_00));
            grad = abs(((newsum-oldsum)/(logdetS_00+oldsum)));
         else;
            %
            % computing the gradient vector
            %
            check_nan = sum(isnan(vec(betainit)));
            if (isalmostequal(check_nan,0)==1)&(rank((betainit'*S_11*betainit))==size(betainit,2));
               alphainit = (S_01*betainit)/(betainit'*S_11*betainit);
               Omegainit = S_00-(((S_01*betainit)/(betainit'*S_11*betainit))*betainit'*S_10);
            else;
               alphainit = (S_01*beta)/(beta'*S_11*beta);
               Omegainit = S_00-(((S_01*beta)/(beta'*S_11*beta))*beta'*S_10);
            end;
            inv_Omegainit = Omegainit\eye(n);
            grad = T*vec(alphainit)'*kron(eye(r),inv_Omegainit*(S_01-(alphainit*betainit'*S_11)))*bH;
            grad = max(abs(grad));
         end;
         oldlambda = newlambda;
         it=it+1;
      end;
      %
      % we're done
      %
   end;
   %
   betar = betainit;
   mycheck = 1;
   file = strcat(modelsdir,'normalize-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.norm');
   if fileexist(file)==1;
      h = loaddata(file);
      %
      % Make sure that normalization works properly
      %
      % 1. check the length of h and fix if too short
      %
      if size(h,1)<r;
         hn = size(h,1)+1;
         for k=hn:r;
            si = sivec(k,1);
            sj = size(H,2);
            if k==1;
               Hsel = [eye(si);zeros(sj-si,si)];
            elseif k==r;
               Hsel = [zeros(sj-si,si);eye(si)];
            else;
               sk = sivec(1,1);
               for j=2:k-1;
                  sk = sk+sivec(j,1);
               end;
               Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
            end;
            Hi = H*Hsel;
            for g=1:size(Hi,1);
               if abs(Hi(g,1))>1.0e-006;
                  h = [h;g];
                  g = size(Hi,1)+1;
               end;
            end;
         end;
      end;
      %
      % 2. check all coefficients to make sure they are valid
      %
      h = h(1:r,1);
      for k=1:r;
         si = sivec(k,1);
         sj = size(H,2);
         if k==1;
            Hsel = [eye(si);zeros(sj-si,si)];
         elseif k==r;
            Hsel = [zeros(sj-si,si);eye(si)];
         else;
            sk = sivec(1,1);
            for j=2:k-1;
               sk = sk+sivec(j,1);
            end;
            Hsel = [zeros(sk,si);eye(si);zeros(sj-si-sk,si)];
         end;
         Hi = H*Hsel;
         mynorm = h(k,1);
         if max(abs(Hi(mynorm,:)))<1.0e-006;
            for l=1:r;
               if abs(Hi(l,1))>1.0e-006;
                  h(k,1) = l;
                  l = r+1;
               end;
            end;
         end;
      end;
      %
      % we are now ready to normalize betar
      %
      for i=1:r;
         normcoeffi = h(i,1);
         normbetai = betar(normcoeffi,i);
         if abs(normbetai)<1.0e-006;
            normbetai = 1;
            mycheck = 0;
         end;
         for j=1:nq1;
            betar(j,i) = betar(j,i)/normbetai;
         end;
      end;
   end;
end;

%
% end of beta_alt_estimate.m
%
