%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI for determining identifying restrictions   %
%          in structural models                                  %
%                                                                %
%          Function: identmatdlg                                 %
%                                                                %
%          Input:                                                %
%                        selector: case switch function          %
%                        cm: structure with model info           %
%                        type_var: string - short_run, long_run  %
%                            or c_matrix                         %
%                                                                %
%          Output:                                               %
%                        h: handle                               %
%                                                                %
%          This version:        May 18, 2006                     %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = identmatdlg(selector,cm,type_var)

if strcmp(selector,'init')==1;
   tm = cm;
   tm.type = type_var;
   curr_ini = find_inisettings;
   myvars = vecstr(tm.evars);
   thisexit = 0;
   %
   % Determining the number of restrictions (default value)
   % and the maximum number of parameters per restriction
   %
   tm.oldF = tm.F;
   tm.numres = size(tm.F,1);
   tm.numelem = floor(size(tm.F,2)/3);
   if size(tm.F)==[1 6];
      if tm.F==zeros(1,6);
         myclear = 'off';
      else;
         myclear = 'on';
      end;
   else;
      myclear = 'on';
   end;
   %
   % Setting the screensize, height and width
   %
   realscrsz = get(0,'ScreenSize');
   heightf = tm.numres*20+(tm.numres-1)*2+46;
   widthf = 210+(tm.numelem-1)*115;
   if widthf<357;
      widthf = 357;
   elseif widthf+28>realscrsz(3);
      widthf = realscrsz(3)-28;
   end;
   if heightf>realscrsz(4)-200;
      heightf = realscrsz(4)-200;
   end;
   height = heightf+150;
   width = widthf+28;
   thiselem = floor((realscrsz(3)-123)/115);
   %
   numresstr = '1';
   %
   if strcmp(tm.type,'short_run')==1;
      tm.k = tm.n;
      tm.ftype = 'F-';
      tm.nr = tm.n;
   elseif strcmp(tm.type,'long_run')==1;
      if tm.r<tm.n;
         tm.k = tm.n-tm.r;
      else;
         tm.k = tm.n;
      end;
      tm.ftype = 'LF-';
      tm.nr = tm.n;
   else;
      if tm.r<tm.n;
         tm.k = tm.n-tm.r;
      else;
         tm.k = tm.n;
      end;
      tm.ftype = 'C-';
      tm.nr = tm.k;
   end;
   %
   deleteenable = 'off';
   file = strcat(tm.modelsdir,tm.ftype,int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
   if fileexist(file)==1;
      deleteenable = 'on';
   end;
   %
   for i=2:tm.n*tm.nr;
      numresstr = [numresstr '|' num2str(i)];
   end;
   numelemstr = '1';
   for i=2:min([tm.n*tm.n thiselem]);
      numelemstr = [numelemstr '|' num2str(i)];
   end;
   if tm.numelem>min([(tm.n-1)*tm.n thiselem]);
      tm.numelem = min([(tm.n-1)*tm.n thiselem]);
      tm.F = [tm.F(:,1:2+3*(tm.numelem-1)) tm.F(:,size(tm.F,2))];
   end;
else;
   thisexit = 1;
%   identmatgui = get(0,'CurrentFigure');
   identmatgui = findobj('Type','figure','Tag','IdentMatGUI')';
   identmat = get(identmatgui,'UserData');
   curr_ini = get(identmat.undo,'UserData');
   tm = curr_ini.models;
end;

switch selector;
   case 'init';

      fix_height = 0;
      if height>realscrsz(4)-179;
         height = realscrsz(4)-179;
         heightf = height-150;
         fix_height = 1;
         header_height = heightf+123;
         if (widthf)-(210+((tm.numelem-1)*115))<20;
            widthf = 230+((tm.numelem-1)*115);
            width = widthf+28;
         end;
      end;

      identmatgui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','identmatdlg.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-width)/2 (realscrsz(4)-height-125)/2 width height+125], ...
         'Tag','IdentMatGUI', ...
         'Resize','off', ...
         'Name','Identifying Restrictions', ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'CloseRequestFcn','identmatdlg exit', ...
         'ToolBar','none');

      if matlabnumber>=7.0;
         set(identmatgui,'DockControl','off');
      end;

      if strcmp(tm.type,'short_run')==1;
         set(identmatgui,'Name','Contemporaneous Identifying Restrictions');
         axesbox([2 2 width-2 height+115],'Select Restrictions on B',115,[0.5 1]);
      elseif strcmp(tm.type,'long_run')==1;
         set(identmatgui,'Name','Long-Run Identifying Restrictions');
         axesbox([2 2 width-2 height+115],'Select Restrictions on A=C*B',140,[0.5 1]);
      else;
         set(identmatgui,'Name','C Restrictions');
         axesbox([2 2 width-2 height+115],'Select Restrictions on C',115,[0.5 1]);
      end;

      %
      % GUI Header
      %

      mycons = getstoredimages;

      if strcmp(tm.type,'short_run')==1;
         header_txt = 'Contemporaneous Restrictions';
         desc_txt = 'Select the number of restrictions on B you''d like to impose, the maximum number of parameters per restriction, and enter the restrictions. Press "Done" to finish or "Cancel" to cancel.';
         dialog_header_fcn([14 height+20 widthf 82],mirrorimage(maketrans(mycons.sr_restbig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      elseif strcmp(tm.type,'long_run')==1;
         header_txt = 'Long-Run Restrictions';
         desc_txt = 'Select the number of restrictions on A = C*B you''d like to impose, the maximum number of parameters per restriction, and enter the restrictions. Press "Done" to finish or "Cancel" to cancel.';
         dialog_header_fcn([14 height+20 widthf 82],mirrorimage(maketrans(mycons.lr_restbig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      else;
         header_txt = 'C Restrictions';
         desc_txt = 'Select the number of restrictions on C you''d like to impose, the maximum number of parameters per restriction, and enter the restrictions. Press "Done" to finish or "Cancel" to cancel.';
         dialog_header_fcn([14 height+20 widthf 82],mirrorimage(maketrans(mycons.c_restbig_image,[160 160 164],[1 1 1])),header_txt,desc_txt);
      end;

      %
      % Outer axis for F matrix
      %

      axesbox([14 153 widthf heightf],'Restrictions',60,[0.5 1]);

      %
      % Outer axis for restrictions parameter controls
      %

      axesbox([14 14 width-130 125],'Restriction Parameters',110,[0.5 1]);

      %
      % Edit control for element (i,j) in Gmat
      %
      
      identmat.editcontrols = [];
      identmat.restcontrols = [];

      for i=1:tm.numres;

         s1 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[26 165+(i-1)*22 70 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','right', ...
            'String',['Restriction ' num2str(tm.numres-i+1) ':'], ...
            'Tag',['RestText_1_' int2str(i)]);

         s2 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[100 165+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String','(', ...
            'Tag',['RestText_2_' int2str(i)]);

         identmat.editbox1 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[105 167+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.F(tm.numres-i+1,1)), ...
            'Enable','on', ...
            'Callback','identmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 1 tm.F(tm.numres-i+1,1)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(1)]);

         s3 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[135 165+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String',',', ...
            'Tag',['RestText_3_' int2str(i)]);

         identmat.editbox2 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 1], ...
            'Position',[140 167+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.F(tm.numres-i+1,2)), ...
            'Enable','on', ...
            'Callback','identmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 2 tm.F(tm.numres-i+1,2)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(2)]);

         s4 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[170 165+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String',')', ...
            'Tag',['RestText_4_' int2str(i)]);

         if i==tm.numres;

            s5 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[105 165+tm.numres*22 65 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','Row,Column', ...
               'Tag','RowCol_1');
         else;
            s5 = [];
         end;
         
         new_controls = [];
         s10_controls = [];
         rest_controls = [];
         
         for j=1:tm.numelem-1;

            s6 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[175+(j-1)*115 165+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','+', ...
               'Tag',['RestText_5_' int2str(i)]);

            identmat.editbox3 = uicontrol('Units','pixels', ...
               'BackgroundColor',[0.6 1 1], ...
               'Position',[180+(j-1)*115 167+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.F(tm.numres-i+1,3+3*(j-1))), ...
               'Enable','on', ...
               'Callback','identmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 3+3*(j-1) tm.F(tm.numres-i+1,3+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(3+3*(j-1))]);

            s7 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[210+(j-1)*115 165+(i-1)*22 10 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String','x(', ...
               'Tag',['RestText_6_' int2str(i)]);

            identmat.editbox4 = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[220+(j-1)*115 167+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.F(tm.numres-i+1,4+3*(j-1))), ...
               'Enable','on', ...
               'Callback','identmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 4+3*(j-1) tm.F(tm.numres-i+1,4+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(4+3*(j-1))]);

            s8 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[250+(j-1)*115 165+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String',',', ...
               'Tag',['RestText_7_' int2str(i)]);

            identmat.editbox5 = uicontrol('Units','pixels', ...
               'BackgroundColor',[1 1 1], ...
               'Position',[255+(j-1)*115 167+(i-1)*22 30 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','edit', ...
               'HorizontalAlignment','left', ...
               'String',num2str(tm.F(tm.numres-i+1,5+3*(j-1))), ...
               'Enable','on', ...
               'Callback','identmatdlg checkelement', ...
               'UserData',[tm.numres-i+1 5+3*(j-1) tm.F(tm.numres-i+1,5+3*(j-1))], ...
               'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(5+3*(j-1))]);

            s9 = uicontrol('Units','pixels', ...
               'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
               'Position',[285+(j-1)*115 165+(i-1)*22 5 20], ...
               'FontSize',curr_ini.gui_fontsize, ...
               'FontName',curr_ini.gui_fontname, ...
               'FontWeight',curr_ini.gui_fontweight, ...
               'FontAngle',curr_ini.gui_fontangle, ...
               'Style','text', ...
               'HorizontalAlignment','center', ...
               'String',')', ...
               'Tag',['RestText_8_' int2str(i)]);

            if i==tm.numres;

               s10 = uicontrol('Units','pixels', ...
                  'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
                  'Position',[220+(j-1)*115 165+tm.numres*22 65 20], ...
                  'FontSize',curr_ini.gui_fontsize, ...
                  'FontName',curr_ini.gui_fontname, ...
                  'FontWeight',curr_ini.gui_fontweight, ...
                  'FontAngle',curr_ini.gui_fontangle, ...
                  'Style','text', ...
                  'HorizontalAlignment','center', ...
                  'String','Row,Column', ...
                  'Tag',['RowCol_' int2str(j+1)]);
            else;
               s10 = [];
            end;
            
            new_controls = [new_controls s6 identmat.editbox3 s7 identmat.editbox4 s8 identmat.editbox5 s9];
            s10_controls = [s10_controls s10];
            rest_controls = [rest_controls identmat.editbox3 identmat.editbox4 identmat.editbox5];

         end;

         s11 = uicontrol('Units','pixels', ...
            'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
            'Position',[175+(tm.numelem-1)*115 165+(i-1)*22 5 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','text', ...
            'HorizontalAlignment','center', ...
            'String','=', ...
            'Tag',['RestText_9_' int2str(i)]);

         identmat.editbox6 = uicontrol('Units','pixels', ...
            'BackgroundColor',[1 1 0.6], ...
            'Position',[180+(tm.numelem-1)*115 167+(i-1)*22 30 20], ...
            'FontSize',curr_ini.gui_fontsize, ...
            'FontName',curr_ini.gui_fontname, ...
            'FontWeight',curr_ini.gui_fontweight, ...
            'FontAngle',curr_ini.gui_fontangle, ...
            'Style','edit', ...
            'HorizontalAlignment','left', ...
            'String',num2str(tm.F(tm.numres-i+1,tm.numelem*3)), ...
            'Enable','on', ...
            'Callback','identmatdlg checkelement', ...
            'UserData',[tm.numres-i+1 tm.numelem*3 tm.F(tm.numres-i+1,tm.numelem*3)], ...
            'Tag',['EditBox_' int2str(tm.numres-i+1) '_' int2str(tm.numelem*3)]);

         identmat.editcontrols = [[s1 s2 identmat.editbox1 s3 identmat.editbox2 s4 new_controls s11 identmat.editbox6];identmat.editcontrols];
         identmat.restcontrols = [[s1 identmat.editbox1 identmat.editbox2 rest_controls identmat.editbox6];identmat.restcontrols];

      end;
      
      identmat.headercontrols = [s5 s10_controls];

      %
      % fix positions of controls if need by and add sliders
      %
      
      if fix_height==1;
         for i=1:size(identmat.headercontrols,2);
            pos = get(identmat.headercontrols(1,i),'Position');
            pos(2) = header_height;
            set(identmat.headercontrols(1,i),'Position',pos);
         end;
         hpos = header_height-22;
         c_rows = 0;
         identmat.vpositions = [];;
         for i=1:size(identmat.editcontrols,1);
            if hpos>=165;
               identmat.vpositions = [identmat.vpositions;hpos];
               for j=1:size(identmat.editcontrols,2);
                  pos = get(identmat.editcontrols(i,j),'Position');
                  if strcmp(get(identmat.editcontrols(i,j),'Style'),'text')==1;
                     pos(2) = hpos;
                  elseif strcmp(get(identmat.editcontrols(i,j),'Style'),'edit')==1;
                     pos(2) = hpos+2;
                  end;
                  set(identmat.editcontrols(i,j),'Position',pos);
               end;
               last_pos = hpos;
               hpos = hpos-22;
               c_rows = c_rows+1;
            else;
               hpos = 0;
               for j=1:size(identmat.editcontrols,2);
                  pos = get(identmat.editcontrols(i,j),'Position');
                  pos(2) = 0;
                  set(identmat.editcontrols(i,j),'Position',pos,'Visible','off');
               end;
            end;
         end;
         identmat.c_rows = c_rows;
         %
         % add a vertical slider
         %
         slider_pos = [pos(1)+30 last_pos 20 header_height-last_pos];
         %
         identmat.vslider = uicontrol('Units','pixels', ...
            'BackgroundColor',(get(0,'defaultuicontrolbackgroundcolor')+[1 1 1])/2, ...
            'Position',slider_pos, ...
            'Style','slider', ...
            'Min',identmat.c_rows, ...
            'Max',size(identmat.editcontrols,1), ...
            'Value',size(identmat.editcontrols,1), ...
            'Callback','gmatdlg vslider', ...
            'Enable','on', ...
            'Tag','VerticalSlider');

         if 2/(size(identmat.editcontrols,1)-identmat.c_rows)<=1;
            set(identmat.vslider,'SliderStep',[1/(size(identmat.editcontrols,1)-identmat.c_rows) 2/(size(identmat.editcontrols,1)-identmat.c_rows)]);
         else;
            set(identmat.vslider,'SliderStep',[0.9 1.0],'UserData',1);
         end;

      end;

      %
      % Number of restrictions control
      %

      identmat.text = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 95 120 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'UserData',tm.F, ...
         'String','Number of restrictions:', ...
         'Tag','NumResText');


      identmat.numres = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-175 100 45 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.numres, ...
         'String',numresstr, ...
         'UserData','done', ...
         'CallBack','identmatdlg changeIdentmat', ...
         'Tag','NumResPopup');

      %
      % Number of parameters control
      %

      uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[30 30 180 20], ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Style','text', ...
         'HorizontalAlignment','left', ...
         'String','Maximum #parameters per restriction:', ...
         'Tag','NumParmText');

      identmat.numelem = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[width-175 35 45 20], ...
         'Style','popupmenu', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'Value',tm.numelem, ...
         'String',numelemstr, ...
         'CallBack','identmatdlg changeIdentmat', ...
         'UserData','working', ...
         'Tag','NumElemPopup');

      %
      % Delete file button
      %

      identmat.delete = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 120 85 20], ...
         'String','Delete', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','identmatdlg delete', ...
         'Enable',deleteenable, ...
         'Tag','UndoButton');

      %
      % Undo button
      %

      identmat.undo = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 95 85 20], ...
         'String','Undo', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','identmatdlg undo', ...
         'Enable','off', ...
         'Tag','UndoButton');

      %
      % Clear button
      %

      identmat.clear = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 70 85 20], ...
         'String','Clear', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','identmatdlg clear', ...
         'Enable',myclear, ...
         'Tag','ClearButton');

      %
      % Done button
      %

      identmat.continue = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 45 85 20], ...
         'String','Done', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','identmatdlg exit', ...
         'UserData','waiting', ...
         'Enable','on', ...
         'Tag','ContinueButton');

      %
      %  Cancel button
      %

      identmat.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[width-100 20 85 20], ...
         'String','Cancel', ...
         'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
         'CallBack','identmatdlg cancel', ...
         'Enable','on', ...
         'UserData',0, ...
         'Tag','CancelButton');

      set(identmatgui,'UserData',identmat,...
         'HandleVisibility','callback');

   case 'vslider'
      slider_val = get(identmat.vslider,'Value');
      if isempty(get(identmat.vslider,'UserData'))==0;
         if isequal(slider_val,round(slider_val))==0;
            slider_val = round(slider_val);
            set(identmat.vslider,'Value',slider_val);
         end;
      end;
      if isint(slider_val)==0;
         slider_val = round(slider_val);
      end;
      set(identmat.restcontrols,'Visible','off');
      first_con = size(identmat.restcontrols,1)-slider_val+1;
      last_con = first_con+identmat.c_rows-1;
      num = 1;
      for i=first_con:last_con;
         for j=1:size(identmat.restcontrols,2);
            pos = get(identmat.restcontrols(i,j),'Position');
            if j==1;
               pos(1,2) = identmat.vpositions(num,1);
            else;
               pos(1,2) = identmat.vpositions(num,1)+2;
            end;
            set(identmat.restcontrols(i,j),'Position',pos,'Visible','on');
         end;
         num = num+1;
      end;
   case 'delete'
      file = strcat(tm.modelsdir,tm.ftype,int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
      if curr_ini.sillyq==0;
         if strcmp(tm.type,'short_run')==1;
            txt = 'Are you sure you want to delete the file with identifying contemporaneous restrictions?';
         elseif strcmp(tm.type,'long_run')==1;
            txt = 'Are you sure you want to delete the file with identifying long-run restrictions?';
         else;
            txt = 'Are you sure you want to delete the file with C restrictions?';
         end;
         answer = query(txt,'question',120,'Delete File',350,'no');
      else;
         answer = 'Yes';
      end;
      if strcmp(answer,'Yes')==1;
         delete_file_fcn(file)
         set(identmat.delete,'Enable','off');
      end;
   case 'undo'
      set(identmat.text,'UserData',tm.oldF);
      set(identmat.numres,'UserData','redraw');
      set(identmatgui,'UserData',identmat);
      identmatdlg('exit');
   case 'changeIdentmat'
      newnumres = get(identmat.numres,'Value');
      newnumelem = get(identmat.numelem,'Value');
      change = 0;
      if newnumres>tm.numres;
         tm.F = [tm.F;zeros(newnumres-tm.numres,3*tm.numelem)];
         tm.numres = newnumres;
         change = 1;
      elseif newnumres<tm.numres;
         tm.F = tm.F(1:newnumres,:);
         tm.numres = newnumres;
         change = 1;
      end;
      if newnumelem>tm.numelem;
         tm.F = [tm.F(:,1:size(tm.F,2)-1) zeros(size(tm.F,1),(newnumelem-tm.numelem)*3) tm.F(:,size(tm.F,2))];
         change = 1;
      elseif newnumelem<tm.numelem;
         tm.F = [tm.F(:,1:2+3*(newnumelem-1)) tm.F(:,size(tm.F,2))];
         change = 1;
      end;
      if change==1;
         set(identmat.text,'UserData',tm.F);
         set(identmat.numres,'UserData','redraw');
         set(identmatgui,'UserData',identmat);
         identmatdlg('exit');
      else;
      end;
   case 'checkelement'
      whichelem = gcbo;
      currelem = get(whichelem,'Userdata');
      if isempty(currelem)==0;
         currvalue = get(whichelem,'String');
         currvalue = strrep(currvalue,',','.');
         currvalue = mystr2num(currvalue);
         if isempty(currvalue)==0;
            %
            % check if value is row or col and adjust it
            % if necessary (i.e. row,col must be an integer
            % and row =1,...,n   col=1,...,r
            %
            type_var = 0;
            if floor(currelem(1,2)/3)<(currelem(1,2)/3);
               for i=1:tm.numelem;
                  for j=1:2;
                     k=j+3*(i-1);
                     if round(k)==round(currelem(1,2));
                        type_var = j;
                        j = 3;
                        i = tm.numelem+1;
                     end;
                  end;
               end;
               currvalue = floor(currvalue);
               if type_var==1;
                  if (currvalue<1)|(currvalue>tm.n);
                     currvalue = 0;
                  end;
               else;
                  if (currvalue<1)|(currvalue>tm.n);
                     currvalue = 0;
                  end;
               end;
            end;
            tm.F(currelem(1,1),currelem(1,2)) = currvalue(1,1);
            set(whichelem,'UserData',[currelem(1,1:2) currvalue(1,1)]);
            set(whichelem,'String',num2str(currvalue(1,1)));
            if get(whichelem,'BackgroundColor')==[1 1 1];
               set(whichelem,'BackgroundColor',[1 0.75 0.75]);
            elseif get(whichelem,'BackgroundColor')==[0.6 1 1];
               set(whichelem,'BackgroundColor',[0.2 1 1]);
            elseif get(whichelem,'BackgroundColor')==[1 1 0.6];
               set(whichelem,'BackgroundColor',[1 1 0.2]);
            end;
            set(identmat.undo,'Enable','on');
            if strcmp(get(identmat.clear,'Enable'),'off')==1;
               set(identmat.clear,'Enable','on');
            end;
         else;
            set(whichelem,'String',num2str(currelem(1,3)));
         end;
      end;
   case 'exit'
      cancel = get(identmat.cancel,'UserData');
      if cancel==1;
         closeexit = 1;
      else;
         closeexit = 1;
         if strcmp(get(identmat.numres,'UserData'),'redraw')==0;
            if strcmp(get(identmat.continue,'UserData'),'done')==0;
               [Rmat,rvec] = rmatrix(tm.F,tm.n,tm.n);
               check_rank = (rank(Rmat)==size(tm.F,1));
               if (strcmp(tm.type,'short_run')==0)&(tm.r<tm.n);
                  %
                  % need to make sure that any restrictions on beta are satisfied
                  % and do not make restrictions on C*B or C redundant
                  %
                  if tm.restrict(1,2)==1;
                     %
                     % create a random beta which satisfies the selected restrictions
                     %
                     beta = [];
                     for i=1:tm.r;
                        file = strcat(tm.modelsdir,'H_',num2str(i),'-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.rest');
                        Hmat = loaddata(file);
                        beta = [beta Hmat*randn(size(Hmat,2),1)];
                     end;
                     %
                     % now we normalize
                     %
                     file = strcat(tm.modelsdir,'normalize-',num2str(tm.n),'x',num2str(tm.r),'x',num2str(tm.dcoint+tm.q1),'-',tm.modelfile,'.norm');
                     h_vec = loaddata(file);
                     for i=1:tm.r;
                        norm_var = h_vec(i,1);
                        normbetai = beta(norm_var,i);
                        if abs(normbetai)<1.0e-006;
                           normbetai = 1;
                        end;
                        for j=1:size(beta,1);
                           beta(j,i) = beta(j,i)/normbetai;
                        end;
                     end;
                     beta = beta(1:tm.n,:);
                     beta_orth = null(beta','r');
                  else;
                     beta_orth = randn(tm.n,tm.n-tm.r);
                  end;
                  Rmat = Rmat*kron(eye(tm.n),beta_orth);
               end;
               %
               if rank(Rmat)==size(tm.F,1);
                  checkfmat = null(Rmat,'r');
                  checkfmat = checkfmat*randn(size(checkfmat,2),1);
                  checkfmat = checkfmat+((Rmat'/(Rmat*Rmat'))*rvec);
                  if (strcmp(tm.type,'short_run')==1)|(tm.r==tm.n);
                     checkfmat = vecinv(checkfmat,tm.n);
                  else;
                     checkfmat = vecinv(checkfmat,tm.n-tm.r);
                     checkfmat = beta_orth*checkfmat;
                  end;
                  if rank(checkfmat)==tm.k;
                     file = strcat(tm.modelsdir,tm.ftype,int2str(tm.n),'x',int2str(tm.r),'-',tm.modelfile,'.rest');
                     myprintstr = '%2.4f';
                     for i=2:size(tm.F,2);
                        myprintstr = [myprintstr ' %2.4f'];
                     end;
                     myprintstr = [myprintstr '\n'];
                     fid = fopen(file,'wt');
                     fprintf(fid,myprintstr,tm.F');
                     fclose(fid);
                     set(identmat.delete,'Enable','on');
                  else;
                     closeexit = 0;
                     if strcmp(tm.type,'short_run')==1;
                        txt = ['The restrictions you have specified implies that B has rank ' num2str(rank(checkfmat)) ', i.e. less than the rank of the covariance matrix of the residuals. Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on B - Information',120,500);
                     elseif strcmp(tm.type,'long_run')==1;
                        txt = ['The restrictions you have specified implies that A=C*B has rank ' num2str(rank(checkfmat)) ', i.e. less than ' num2str(tm.n-tm.r,'%0.0f') '. Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on A=C*B - Information',120,500);
                     else;
                        txt = ['The restrictions you have specified implies that C has rank ' num2str(rank(checkfmat)) ', i.e. less than the rank of the covariance matrix of the residuals. Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on C - Information',120,500);
                     end;
                  end;
               else;
                  closeexit = 0;
                  if tm.numres>1;
                     if strcmp(tm.type,'short_run')==1;
                        txt = ['The ' num2str(tm.numres) ' restrictions you have specified for B are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '. Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on B - Information',130,500);
                     elseif strcmp(tm.type,'long_run')==1;
                        if (check_rank==1)&(tm.r<tm.n);
                           add_text = ' This is probably due to an inconsistency between your selected restrictions and the beta matrix.';
                        else;
                           add_text = '';
                        end;
                        txt = ['The ' num2str(tm.numres) ' restrictions you have specified for A=C*B are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '.' add_text ' Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on A=C*B - Information',150,500);
                     else;
                        txt = ['The ' num2str(tm.numres) ' restrictions you have specified for C are linearly dependent, i.e. the rank of the restrictions matrix is ' num2str(rank(Rmat)) '. Please respecify or select ''Cancel''!'];
                        about(txt,'warning','Restrictions on C - Information',130,500);
                     end;
                  else;
                     if strcmp(tm.type,'short_run')==1;
                        txt = 'You haven''t specified a proper restriction for B. Please respecify or select ''Cancel''!';
                        about(txt,'warning','Restrictions on B - Information',110,350);
                     elseif strcmp(tm.type,'long_run')==1;
                        txt = 'You haven''t specified a proper restriction for A=C*B. Please respecify or select ''Cancel''!';
                        about(txt,'warning','Restrictions on A=C*B - Information',110,350);
                     else;
                        txt = 'You haven''t specified a proper restriction for C. Please respecify or select ''Cancel''!';
                        about(txt,'warning','Restrictions on C - Information',110,350);
                     end;
                  end;
               end;
            end;
         end;
      end;
      if closeexit==1;
         set(identmatgui,'Visible','off');
         drawnow;
         set(identmat.continue,'UserData','done');
         if strcmp(get(identmat.numelem,'UserData'),'done')==1;
%            delete(identmatgui);
         end;
      end;
   case 'clear'
      if curr_ini.sillyq==0;
         txt = 'Are you sure you want to empty the set of restrictions?';
         answer = query(txt,'question',120,'Clear Restrictions',350,'no');
      else;
         answer = 'Yes';
      end;
      if strcmp(answer,'Yes')==1;
         set(identmat.text,'UserData',zeros(1,6));
         set(identmat.numres,'UserData','redraw');
         set(identmatgui,'UserData',identmat);
         identmatdlg('exit');
      end;
   case 'cancel'
      set(identmat.cancel,'UserData',1);
      set(identmatgui,'UserData',identmat);
      identmatdlg('exit');
end;


if strcmp(selector,'init')==1;
   if (strcmp(computer,'PCWIN')==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      if strcmp(tm.type,'short_run')==1;
         ico_file = 'short-run.ico';
      elseif strcmp(tm.type,'long_run')==1;
         ico_file = 'long-run.ico';
      else;
         ico_file = 'crest.ico';
      end;
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(identmatgui,'Name') ' ' fix_filepath([pwd '\icons\' ico_file])];
      dos(prog);
      if (iswinnt==1)&(strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(identmat.clear,'UserData',pid);
      end;
   end;
   set(identmatgui,'Visible','on');
   drawnow;
   drawnow;
   if (iswinnt==1)&(iscompiled==1)&(matlabnumber<7);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(identmatgui,'Name') ' 1'];
      dos(prog);
      drawnow;
   elseif matlabnumber>=7;
      uicontrol(identmat.cancel);
   end;
end;

if nargout==1;
   h = identmatgui;
end;

curr_ini.models = tm;
set(identmat.undo,'UserData',curr_ini);

if thisexit==0;
   waitfor(identmat.continue,'UserData','done');
end;

%
% end of identmatdlg.m
%
