function log_pm_beta = margin_rank_beta(Omega,alpha,beta,epsilon,lambda_alpha,h_vec,H_mat)

%
% Transform beta into the vector psi satisfying
%
%  vec(beta) = h_vec + H_mat*psi
%
% The prior distribution for psi is N(0,Sigma_psi), where
%
%  Sigma_psi = inverse( H_mat' * inverse(Sigma_beta) * H_mat )
%
%  Sigma_beta = kron( inverse(alpha'*inverse(Omega)*alpha) , lambda_alpha^2 * I  )
%
% where I is the identity with dimension equal to the number of rows of beta
%

psi = inverse(H_mat'*H_mat)*H_mat'*(vec(beta)-h_vec);
size_b = size(beta,1);
Sigma_beta_inv = kron((alpha'*inverse(Omega)*alpha),((1/(lambda_alpha^2))*eye(size_b)));
Sigma_psi = inverse(H_mat'*Sigma_beta_inv*H_mat);
lpr_b = log_norm(psi,zeros(size(psi)),Sigma_psi);
log_pm_beta = lpr_b+loglikefcn(Omega,epsilon);

%
% end of margin_rank_beta.m
%
