%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for simulating the asymptotic       %
%          distribution of the Nyblom tests for the constancy    %
%          of beta                                               %
%                                                                %
%          Function: nyblom_dist                                 %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       cm: structure with model info            %
%                                                                %
%          Output:                                               %
%                                                                %
%          This version:        June 22, 2006                    %
%          Written by:          Anders Warne                     %
%                               Copyright (c) 2001-2006          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function nyblom_dist(selector,cm)

%
% GUI for simulating the Nyblom distributions
%

if (nargin==0)|(strcmp(selector,'init')==1);
   tm = cm;
   %
   % toolbar images
   %
   button_images = read_images;
   %
   % more initialization
   %
   selector = 'init';
   my_exit = 1;
   tm.const_model = [0 0 0 0 0];
   if tm.deterselect(1)==1;
      tm.const_model(3) = 1;
   elseif tm.deterselect(2)==1
      tm.const_model(2) = 1;
   elseif tm.deterselect(3)==1;
      tm.const_model(5) = 1;
   else;
      tm.const_model(4) = 1;
   end;
   selector = 'init';
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   tm.realscrsz = get(0,'ScreenSize');
   tm.nyblom_run = 0;
   %
   % read var.in
   %
   curr_ini = find_inisettings;
   my_T = curr_ini.nDraw;
   rep = curr_ini.nRep;
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   nRep_value = 1;
   for i=1:size(repvalues,2);
      if curr_ini.nRep==repvalues(1,i)-1;
         nRep_value = i;
         break;
      end;
   end;
   if direxist(curr_ini.simulatedir)==0;
      mystatus = makedirs(curr_ini.simulatedir);
   else;
      mystatus = 2;
   end;
   if mystatus==0;
      curr_ini.simulatedir = pwd;
      if strcmp(computer,'PCWIN')==1;
         curr_ini.simulatedir = [curr_ini.simulatedir '\'];
      end;
   end;
   if isnumeric(curr_ini.external)==0;
      curr_ini.external = 0;
   end;
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      view_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      nyblom_mat = load(full_mat);
      nyblom_data = [nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
   else;
      view_enable = 'off';
      nyblom_data = [];
      full_mat = '';
      full_enable = 'off';
   end;
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(tm.n) '.' num2str(tm.r) '-' num2str(my_T) '.' num2str(rep+1) '-trend.txt'];
   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
   end;
   tm.interpolate = curr_ini.interpolate;
   if strcmp(tm.interpolate,'nearest')==1;
      tm.interpolate_value = 1;
   elseif strcmp(tm.interpolate,'linear')==1;
      tm.interpolate_value = 2;
   elseif strcmp(tm.interpolate,'spline')==1;
      tm.interpolate_value = 3;
   elseif strcmp(tm.interpolate,'cubic')==1;
      tm.interpolate_value = 4;
   elseif strcmp(tm.interpolate,'knorm')==1;
      tm.interpolate_value = 5;
   elseif strcmp(tm.interpolate,'kepan')==1;
      tm.interpolate_value = 6;
   elseif strcmp(tm.interpolate,'krect')==1;
      tm.interpolate_value = 7;
   elseif strcmp(tm.interpolate,'ktria')==1;
      tm.interpolate_value = 8;
   elseif strcmp(tm.interpolate,'kbiwe')==1;
      tm.interpolate_value = 9;
   elseif strcmp(tm.interpolate,'ktriw')==1;
      tm.interpolate_value = 10;
   elseif strcmp(tm.interpolate,'klapl')==1;
      tm.interpolate_value = 11;
   elseif strcmp(tm.interpolate,'klogi')==1;
      tm.interpolate_value = 12;
   end;
else;
   my_exit = 0;
   nyblom_gui = findobj('Type','figure','Tag','NyblomDist')';
   my_nyblom = get(nyblom_gui,'UserData');
   curr_ini = get(my_nyblom.mfilebutton,'UserData');
   tm = curr_ini.models;
   button_images = curr_ini.images;
end;

switch selector
case 'init'
   nyblom_gui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','nyblom_dist.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(tm.realscrsz(3)-560)/2 (tm.realscrsz(4)-320)/2 560 320], ...
         'Tag','NyblomDist', ...
         'Visible','off', ...
         'Resize','off', ...
         'Name','Simulate Distributions for Nyblom Tests', ...
         'NumberTitle','off', ...
         'CloseRequestFcn','nyblom_dist done', ...
         'ToolBar','none');

   if matlabnumber>=7.0;
      set(nyblom_gui,'DockControl','off');
   end;

   %
   % File menu
   %

   filemenu = uimenu('Parent',nyblom_gui, ...
      'Label','&File', ...
      'Tag','FileMenu');

   my_nyblom.simulatemenu = uimenu('Parent',filemenu, ...
         'Label','&Run Simulation', ...
         'Callback','nyblom_dist simulate', ...
         'Enable','on', ...
         'Accelerator','R', ...
         'Tag','SimulateMenu');

   my_nyblom.mfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to &m-file', ...
         'Separator','on', ...
         'Accelerator','M', ...
         'Callback','nyblom_dist mfile', ...
         'Enable',full_enable, ...
         'Tag','MFileMenu');

   my_nyblom.matfilemenu = uimenu('Parent',filemenu, ...
         'Label','Save to m&at-file', ...
         'Accelerator','A', ...
         'Enable',full_enable, ...
         'Callback','nyblom_dist matfile', ...
         'Tag','MatFileMenu');

   my_nyblom.summarymenu = uimenu('Parent',filemenu, ...
         'Label','&Simulation Summary', ...
         'Separator','on', ...
         'Callback','nyblom_dist summary', ...
         'UserData',summary_txt, ...
         'Accelerator','S', ...
         'Enable',summary_enable, ...
         'Tag','SummaryMenu');

   my_nyblom.fullmenu = uimenu('Parent',filemenu, ...
         'Label','&Full Simulation', ...
         'Callback','nyblom_dist full', ...
         'Accelerator','F', ...
         'UserData',full_mat, ...
         'Enable',full_enable, ...
         'Tag','FullMenu');


   if curr_ini.noprint==0;
      my_nyblom.output = uimenu('Parent',filemenu, ...
            'Label','Append to &Output', ...
            'Separator','on', ...
            'Callback','nyblom_dist output', ...
            'Accelerator','O', ...
            'Enable',summary_enable, ...
            'Tag','AppendMenu');
   end;

   uimenu('Parent',filemenu, ...
         'Label','Center &Window', ...
         'Separator','on', ...
         'Accelerator','W', ...
         'Enable','on', ...
         'Callback','center_figure_fcn', ...
         'Tag','CenterMenu');

   my_nyblom.returnmenu = uimenu('Parent',filemenu, ...
         'Label','R&eturn', ...
         'Separator','on', ...
         'Callback','nyblom_dist done', ...
         'Enable','on', ...
         'Tag','MenuFileReturn');

   my_nyblom.filemenu = filemenu;

   %
   % Graph Menu
   %

   graphmenu = uimenu('Parent',nyblom_gui, ...
      'Label','&Graphics', ...
      'Tag','GraphMenu');

   my_nyblom.displaymenu = uimenu('Parent',graphmenu, ...
         'Label','&Graph Distribution', ...
         'Callback','nyblom_dist display', ...
         'Accelerator','G', ...
         'UserData',tm.const_model, ...
         'Enable',view_enable, ...
         'Tag','DisplayMenu');

   my_nyblom.histogrammenu = uimenu('Parent',graphmenu, ...
         'Label','&Histogram of Distribution', ...
         'Callback','nyblom_dist display', ...
         'Accelerator','D', ...
         'Enable',view_enable, ...
         'Tag','HistogramMenu');

   my_nyblom.toolbar = uitoolbar('Parent',nyblom_gui, ...
                     'HandleVisibility','off', ...
                     'Interruptible','on', ...
                     'Clipping','on');

%   xline([1 277 530],[0.5 1]);

   xline([1 319 560],[0.5 1]);

   my_nyblom.simulate = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Run Simulation', ...
                      'CData',button_images.simulate, ...
                      'ClickedCallback','nyblom_dist simulate', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable','on', ...
                      'UserData',0, ...
                      'Tag','Simulate');

   my_nyblom.mfilebutton = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Save to m-file', ...
                      'CData',button_images.mfile, ...
                      'ClickedCallback','nyblom_dist mfile', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MFileButton');

   my_nyblom.matfilebutton = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Save to mat-file', ...
                      'CData',button_images.matfile, ...
                      'ClickedCallback','nyblom_dist matfile', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','MatFileButton');

   my_nyblom.summary = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','View Simulation Summary', ...
                      'CData',button_images.sim_summary, ...
                      'ClickedCallback','nyblom_dist summary', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',summary_enable, ...
                      'Tag','SummaryButton');

   my_nyblom.full = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','View Full Simulation', ...
                      'CData',button_images.sim_full, ...
                      'ClickedCallback','nyblom_dist full', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',full_enable, ...
                      'Tag','FullButton');

   my_nyblom.display = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Graph Distribution', ...
                      'CData',button_images.viewdist, ...
                      'ClickedCallback','nyblom_dist display', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'UserData',nyblom_data, ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','ViewDistButton');

   my_nyblom.histogram = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Histogram of Distribution', ...
                      'CData',button_images.bars, ...
                      'ClickedCallback','nyblom_dist display', ...
                      'Separator','off', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'Enable',view_enable, ...
                      'Tag','HistogramButton');

   my_nyblom.done = uipushtool('Parent',my_nyblom.toolbar, ...
                      'TooltipString','Return', ...
                      'CData',button_images.continue, ...
                      'ClickedCallback','nyblom_dist done', ...
                      'Separator','on', ...
                      'Interruptible','on', ...
                      'Clipping','on', ...
                      'UserData','waiting', ...
                      'Enable','on', ...
                      'Tag','Done');

   axesbox([2 2 558 305],'Nyblom Tests',70,[0.5 1]);

   %
   % a program logo
   %

   imageaxes = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[430 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg2,'Clipping','off','Parent',imageaxes);

   imageaxes2 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[470 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg,'Clipping','off','Parent',imageaxes2);

   imageaxes1 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[390 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg3,'Clipping','off','Parent',imageaxes1);

   imageaxes3 = axes('Units','pixels', ...
      'Box','on', ...
      'TickLength',[0 0], ...
      'CameraUpVector',[0 1 0], ...
      'Color',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[510 16 39 39], ...
      'XTickLabelMode','manual', ...
      'YTickLabelMode','manual', ...
      'Tag','AxisLogo', ...
      'XColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'YColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'ZColor',get(0,'defaultuicontrolbackgroundcolor'));

   image('CData',button_images.borg1,'Clipping','off','Parent',imageaxes3);

   axesbox([185 161 361 130],'Parameters',55,[0.5 1]);

   %
   % number of observations per replication
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 250 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of draws per replication:', ...
      'Tag','ObsText');

   my_nyblom.obs = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 255 168 20], ...
      'Value',floor(my_T/100), ...
      'String','100|200|300|400|500|600|700|800|900|1000|1100|1200|1300|1400|1500|1600|1700|1800|1900|2000|2500|3000|4000|5000|6000|7000|8000|9000|10000', ...
      'Style','popupmenu', ...
      'UserData',my_T, ...
      'Callback','nyblom_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ObsPopup');

   %
   % number of replications
   %


   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 225 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of replications:', ...
      'Tag','SimulText');

   my_nyblom.rep = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 230 168 20], ...
      'Value',nRep_value, ...
      'String','100|1,000|2,000|3,000|4,000|5,000|10,000|20,000|30,000|40,000|50,000|100,000|200,000|300,000|400,000|500,000|1,000,000', ...
      'Style','popupmenu', ...
      'Callback','nyblom_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'UserData',rep,...
      'Enable','on', ...
      'Tag','SimulPopup');

   %
   % number of variables
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 200 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of endogenous variables:', ...
      'Tag','EndoVarText');

   my_nyblom.my_n = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 205 168 20], ...
      'Value',tm.n-1, ...
      'String','2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20', ...
      'Style','popupmenu', ...
      'UserData',tm.n, ...
      'Callback','nyblom_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','EndoVarPopup');

   %
   % number of cointegration relations
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 175 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cointegration relations:', ...
      'Tag','CointText');

   my_nyblom.my_r = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 180 168 20], ...
      'Value',tm.r, ...
      'String','1|2|3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19', ...
      'Style','popupmenu', ...
      'UserData',tm.r, ...
      'Callback','nyblom_dist check', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CointPopup');

   %
   % Select interpolation function
   %

   axesbox([16 67 530 80],'Graphics',45,[0.5 1]);

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 105 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Interpolation function:', ...
      'Tag','InterpolateText');

   my_nyblom.interpolate = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 110 168 20], ...
      'Value',tm.interpolate_value, ...
      'String','Nearest neighborhood|Linear|Cubic spline|Cubic|Kernel density normal|Kernel density Epanechnikov|Kernel density rectangular|Kernel density triangular|Kernel density biweight|Kernel density triweight|Kernel density Laplace|Kernel density logistic', ...
      'Callback','nyblom_dist interpolate', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','InterpolatePopup');

   %
   % Number of cells for graphing density functions
   %

   uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 80 250 20], ...
      'Style','text', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'HorizontalAlignment','left', ...
      'String','Number of cells for histograms:', ...
      'Tag','CellText');

   my_nyblom.cells = uicontrol('Units','pixels', ...
      'BackgroundColor',[1 1 1], ...
      'Position',[362 85 168 20], ...
      'Value',1, ...
      'String','20|25|30|35|40|45|50|55|60|65|70|75|80|85|90|95|100', ...
      'Style','popupmenu', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','CellPopup');

   my_nyblom.cdf = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 108 140 20], ...
      'Value',0, ...
      'String','Cumulative distribution', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','cdfCheckbox');

   my_nyblom.adaptive = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 83 140 20], ...
      'Value',0, ...
      'String','Adaptive KDE method', ...
      'Style','checkbox', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','off', ...
      'Tag','adaptiveCheckbox');

   if tm.interpolate_value>=5;
      set(my_nyblom.adaptive,'Enable','on');
   end;

   %
   % Display clock
   %

   my_nyblom.clock = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 36 160 20], ...
      'Value',1, ...
      'String','Show elapsed time', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','TimeCheck');

   my_nyblom.save = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 36 160 20], ...
      'Value',0, ...
      'String','Save full simulation', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','SaveCheck');

   my_nyblom.progress = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[30 16 160 20], ...
      'Value',1, ...
      'String','Show progress dialogue', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','ProgressCheck');

   my_nyblom.mfile = uicontrol('Units','pixels', ...
      'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      'Position',[199 16 160 20], ...
      'Value',0, ...
      'String','Quantiles to m-file', ...
      'Style','checkbox', ...
      'HorizontalAlignment','left', ...
      'FontSize',curr_ini.gui_fontsize, ...
      'FontName',curr_ini.gui_fontname, ...
      'FontWeight',curr_ini.gui_fontweight, ...
      'FontAngle',curr_ini.gui_fontangle, ...
      'Enable','on', ...
      'Tag','MfileCheck');

   %
   % model type
   %

   axesbox([16 161 155 130],'Model',30,[0.5 1]);

   my_nyblom.radio1 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
	       'Position',[30 278 115 20], ...
	       'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(1), ...
         'Enable','on', ...
         'Max',1, ...
         'Visible','off', ...
         'UserData',1, ...
         'HorizontalAlignment','left', ...
      	 'String','No constant', ...
      	 'Tag','ModelRadio1');

   my_nyblom.radio2 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 253 115 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(2), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',2, ...
         'HorizontalAlignment','left', ...
         'Callback','nyblom_dist selectmodel', ...
      	 'String','Restricted constant', ...
      	 'Tag','ModelRadio2');

   my_nyblom.radio3 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 228 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(3), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',3, ...
         'HorizontalAlignment','left', ...
         'Callback','nyblom_dist selectmodel', ...
      	 'String','Constant', ...
      	 'Tag','ModelRadio3');

   my_nyblom.radio4 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 203 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(4), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',4, ...
         'HorizontalAlignment','left', ...
         'Callback','nyblom_dist selectmodel', ...
      	 'String','Restricted linear trend', ...
      	 'Tag','ModelRadio4');

   my_nyblom.radio5 = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
      	 'Position',[30 178 125 20], ...
      	 'FontSize',curr_ini.gui_fontsize, ...
         'FontName',curr_ini.gui_fontname, ...
         'FontWeight',curr_ini.gui_fontweight, ...
         'FontAngle',curr_ini.gui_fontangle, ...
      	 'Style','radiobutton', ...
         'Value',tm.const_model(5), ...
         'Enable','on', ...
         'Max',1, ...
         'UserData',5, ...
         'HorizontalAlignment','left', ...
         'Callback','nyblom_dist selectmodel', ...
      	 'String','Linear trend', ...
      	 'Tag','ModelRadio5');

   set(nyblom_gui,'UserData',my_nyblom,...
         'HandleVisibility','callback');

case 'output'
   txt_str = readtext(lower(get(my_nyblom.summarymenu,'UserData')));
   fout = fopen(tm.outputfile,'at');
   fprintf(fout,'                      Simulation of Nyblom Tests\n                      --------------------------\n');
   for i=5:size(txt_str,2)-4;
      fprintf(fout,'%s\n',txt_str{i});
   end;
   fprintf(fout,'\n===============================================================================\n\n');
   fclose(fout);
case 'interpolate'
   tm.interpolate_value = get(my_nyblom.interpolate,'Value');
   interpol_vec = strvcat('nearest','linear','spline','cubic','knorm','kepan','krect','ktria','kbiwe','ktriw','klapl','klogi');
   tm.interpolate = strtrim(interpol_vec(tm.interpolate_value,:));
   if tm.interpolate_value>=5;
      set(my_nyblom.adaptive,'Enable','on');
   else;
      set(my_nyblom.adaptive,'Enable','off','Value',0);
   end;
case 'mfile'
   result = get(my_nyblom.display,'UserData');
   NyblomMax = result(:,1);
   NyblomMean = result(:,2);
   rep = get(my_nyblom.rep,'UserData');
   my_n = get(my_nyblom.my_n,'UserData');
   my_r = get(my_nyblom.my_r,'UserData');
   my_T = get(my_nyblom.obs,'UserData');
   my_const_model = get(my_nyblom.displaymenu,'UserData');
   new_quantiles = ceil(rep*quantiles_fcn);
   cv_mean = NyblomMean(new_quantiles);
   cv_max = NyblomMax(new_quantiles);
   quantiles = [];
   for i=50:99;
      quantiles = [quantiles;ceil((i/100)*rep)];
   end;
   quant_mean = NyblomMean(quantiles);
   quant_max = NyblomMax(quantiles);
   if my_const_model(1)==1;
      file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
      file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
      file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
      file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
   elseif my_const_model(2)==1;
      file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
      file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
      file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
      file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
   elseif my_const_model(3)==1;
      file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_const.m'];
      file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_const.m'];
      file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_const.m'];
      file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_const.m'];
   elseif my_const_model(4)==1;
      file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
      file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
      file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
      file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
   elseif my_const_model(5)==1;
      file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
      file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
      file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
      file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
   end;
   if fileexist(file_max)==1;
      my_text = ['The file "' getfilename(file_max) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to m-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Saving results to m-files...');
      fid_mean = fopen(file_mean,'wt');
      fid_max = fopen(file_max,'wt');
      fprintf(fid_mean,['function out = ' getname(file_mean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      fprintf(fid_max,['function out = ' getname(file_max) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      for j=1:size(cv_max,1);
         if j==1;
            fprintf(fid_mean,['out = [ ' num2str(cv_mean(1,1),'%1.12f') ';\n']);
            fprintf(fid_max,['out = [ ' num2str(cv_max(1,1),'%1.12f') ';\n']);
         elseif j==size(cv_max,1);
            fprintf(fid_mean,['        ' num2str(cv_mean(j,1),'%1.12f') '];\n\n']);
            fprintf(fid_max,['        ' num2str(cv_max(j,1),'%1.12f') '];\n\n']);
         else;
            fprintf(fid_mean,['        ' num2str(cv_mean(j,1),'%1.12f') ';\n']);
            fprintf(fid_max,['        ' num2str(cv_max(j,1),'%1.12f') ';\n']);
         end;
      end;
      mean_text = ['%%\n%% end of ' getfilename(file_mean) '\n%%\n'];
      fprintf(fid_mean,mean_text);
      fclose(fid_mean);
      max_text = ['%%\n%% end of ' getfilename(file_max) '\n%%\n'];
      fprintf(fid_max,max_text);
      fclose(fid_max);
      fid_qmean = fopen(file_qmean,'wt');
      fid_qmax = fopen(file_qmax,'wt');
      fprintf(fid_qmean,['function out = ' getname(file_qmean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      fprintf(fid_qmax,['function out = ' getname(file_qmax) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
      for j=1:size(quant_max,1);
         if j==1;
            fprintf(fid_qmean,['out = [ ' num2str(quant_mean(1,1),'%1.12f') ';\n']);
            fprintf(fid_qmax,['out = [ ' num2str(quant_max(1,1),'%1.12f') ';\n']);
         elseif j==size(quant_max,1);
            fprintf(fid_qmean,['        ' num2str(quant_mean(j,1),'%1.12f') '];\n\n']);
            fprintf(fid_qmax,['        ' num2str(quant_max(j,1),'%1.12f') '];\n\n']);
         else;
            fprintf(fid_qmean,['        ' num2str(quant_mean(j,1),'%1.12f') ';\n']);
            fprintf(fid_qmax,['        ' num2str(quant_max(j,1),'%1.12f') ';\n']);
         end;
      end;
      mean_text = ['%%\n%% end of ' getfilename(file_qmean) '\n%%\n'];
      fprintf(fid_qmean,mean_text);
      fclose(fid_qmean);
      max_text = ['%%\n%% end of ' getfilename(file_qmax) '\n%%\n'];
      fprintf(fid_qmax,max_text);
      fclose(fid_qmax);
   end;
case 'matfile'
   result = get(my_nyblom.display,'UserData');
   NyblomMax = result(:,1);
   NyblomMean = result(:,2);
   rep = get(my_nyblom.rep,'UserData');
   my_n = get(my_nyblom.my_n,'UserData');
   my_r = get(my_nyblom.my_r,'UserData');
   my_T = get(my_nyblom.obs,'UserData');
   my_const_model = get(my_nyblom.displaymenu,'UserData');
   if my_const_model(1)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif my_const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif my_const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif my_const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif my_const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      my_text = ['The file "' getfilename(full_mat) '" already exists. Are you sure you want to overwrite it?'];
      answer = query(my_text,'question',120,'Save to mat-file',500,'no');
   else;
      answer = 'Yes';
   end;
   if strcmp(answer,'Yes')==1;
      setlogtext('Savings results to mat-files...');
      Number = (1:1:rep)';
      save(full_mat,'Number','NyblomMax','NyblomMean');
      if fileexist(full_mat)==1;
         set(my_nyblom.full,'Enable','on');
         set(my_nyblom.fullmenu,'Enable','on','UserData',full_mat);
      end;
   end;
case 'check'
   T_str = get(my_nyblom.obs,'String');
   my_T = mystr2num(strtrim(T_str(get(my_nyblom.obs,'Value'),:)));
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   rep_val = get(my_nyblom.rep,'Value');
   rep = repvalues(rep_val);
   set(my_nyblom.rep,'UserData',rep);
   my_n = get(my_nyblom.my_n,'Value')+1;
   my_r = get(my_nyblom.my_r,'Value');
   set(my_nyblom.obs,'UserData',my_T);
   set(my_nyblom.my_n,'UserData',my_n);
   set(my_nyblom.my_r,'UserData',my_r);
   %
   % adjusting the view text buttons
   %
   full_mat = '';
   if tm.const_model(1)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
   elseif tm.const_model(2)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
   elseif tm.const_model(3)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
   elseif tm.const_model(4)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
   elseif tm.const_model(5)==1;
      full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
   end;
   if fileexist(full_mat)==1;
      full_enable = 'on';
      if rep>=5000;
         this_text = strvcat(' ',['Collecting data from ' getfilename(full_mat) '...'],'Please hold!');
         mywait = waitdlg(this_text,'information');
         waitf = get(mywait,'UserData');
      end;
      nyblom_mat = load(full_mat);
      nyblom_data = [nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
      if rep>=5000;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
      end;
      %
      % adjusting the Graph Distrbution button
      %
      set(my_nyblom.display,'Enable','on','UserData',nyblom_data);
      set(my_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
      set(my_nyblom.histogram,'Enable','on');
      set(my_nyblom.histogrammenu,'Enable','on');
      set(my_nyblom.mfilebutton,'Enable','on');
      set(my_nyblom.mfilemenu,'Enable','on');
      set(my_nyblom.matfilebutton,'Enable','on');
      set(my_nyblom.matfilemenu,'Enable','on');
   else;
      full_mat = '';
      full_enable = 'off';
%      sim_full = button_images.sim_fulldisable;
      set(my_nyblom.display,'Enable','off','UserData',[]);
      set(my_nyblom.displaymenu,'Enable','off','UserData',tm.const_model);
      set(my_nyblom.histogram,'Enable','off');
      set(my_nyblom.histogrammenu,'Enable','off');
      set(my_nyblom.mfilebutton,'Enable','off');
      set(my_nyblom.mfilemenu,'Enable','off');
      set(my_nyblom.matfilebutton,'Enable','off');
      set(my_nyblom.matfilemenu,'Enable','off');
   end;
   set(my_nyblom.fullmenu,'Enable',full_enable,'UserData',full_mat);
   set(my_nyblom.full,'Enable',full_enable);
   summary_txt = '';
   if tm.const_model(1)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
   elseif tm.const_model(2)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
   elseif tm.const_model(3)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
   elseif tm.const_model(4)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
   elseif tm.const_model(5)==1;
      summary_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
   end;
   if fileexist(summary_txt)==1;
      summary_enable = 'on';
   else;
      summary_txt = '';
      summary_enable = 'off';
%      sim_summary = button_images.sim_summarydisable;
   end;
   if curr_ini.noprint==0;
      set(my_nyblom.output,'Enable',summary_enable);
   end;
   set(my_nyblom.summarymenu,'Enable',summary_enable,'UserData',summary_txt);
   set(my_nyblom.summary,'Enable',summary_enable);
   set(nyblom_gui,'UserData',my_nyblom);
case 'summary'
   set(nyblom_gui,'Visible','off');
   drawnow;
   file = lower(get(my_nyblom.summarymenu,'UserData'));
   prtgui = printgui('init',file,'Structural VAR - Nyblom Tests Simulation Summary',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   myprint = get(prtgui,'UserData');
   set(myprint.print,'UserData','done');
   killguipid(prtgui);
   set(nyblom_gui,'Visible','on');
   drawnow;
   set(nyblom_gui,'UserData',my_nyblom);
case 'full'
   set(nyblom_gui,'Visible','off');
   drawnow;
   rep = get(my_nyblom.rep,'UserData');
   full_mat = lower(get(my_nyblom.fullmenu,'UserData'));
   sp_str = spacestr(curr_ini.decimals-2);
   prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
   prt_str = ['%7.0f   ' prt_val '   ' prt_val];
   my_text = strvcat(' ',[' Number   Max-test  ' sp_str ' Mean-test']);
   abort = '';
   if rep>=5000;
      input_var.title = ['Progress for ' int2str(rep) ' replications'];
      input_var.facecolor = curr_ini.progress_facecolor;
      input_var.startfacecolor = curr_ini.progress_startfacecolor;
      input_var.edgecolor = curr_ini.progress_edgecolor;
      input_var.bgcolor = curr_ini.progress_bgcolor;
      input_var.label = 'Replication number:';
      input_var.stop = 0;
      input_var.clock = 1;
      input_var.name = ['Data in ' getname(full_mat)];
      mywait = progressdlg(0,input_var);
%      set(mywait,'Name',['Data in ' getname(full_mat)]);
      set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      drawnow;
   end;
   nyblom_mat = load(full_mat);
   my_data = [nyblom_mat.Number nyblom_mat.NyblomMax nyblom_mat.NyblomMean];
   for i=1:size(my_data,1);
      if rep>=5000;
         abort = get(mywait,'UserData');
         if strcmp(abort,'cancel')==1;
            break;
         else;
            progressdlg([(i/rep) i]);
         end;
      end;
      my_text = strvcat(my_text,sprintf(prt_str,my_data(i,:)'));
   end;
   my_text = strvcat(my_text,' ');
   if rep>=5000;
      set(mywait,'UserData','done');
      close(mywait);
      drawnow;
   end;
   if strcmp(abort,'cancel')==0;
      textgui(my_text,'Structural VAR - Nyblom Tests Simulation',[(tm.realscrsz(3)-700)/2 (tm.realscrsz(4)-500)/2 700 500],'Results',40);
   end;
   set(nyblom_gui,'Visible','on');
   drawnow;
   set(nyblom_gui,'UserData',my_nyblom);
case 'selectmodel'
   tm.const_model = [0 0 0 0 0];
   ch_val = get(gcbo,'UserData');
   tm.const_model(ch_val) = 1;
   set(my_nyblom.radio1,'Value',tm.const_model(1));
   set(my_nyblom.radio2,'Value',tm.const_model(2));
   set(my_nyblom.radio3,'Value',tm.const_model(3));
   set(my_nyblom.radio4,'Value',tm.const_model(4));
   set(my_nyblom.radio5,'Value',tm.const_model(5));
   curr_ini.models = tm;
   set(my_nyblom.mfilebutton,'UserData',curr_ini);
   set(nyblom_gui,'UserData',my_nyblom);
   nyblom_dist('check');
   curr_ini = get(my_nyblom.mfilebutton,'UserData');
   tm = curr_ini.models;
case 'display'
   result = get(my_nyblom.display,'UserData');
   NyblomMax = result(:,1);
   NyblomMean = result(:,2);
   rep = get(my_nyblom.rep,'UserData');
   my_n = get(my_nyblom.my_n,'UserData');
   my_r = get(my_nyblom.my_r,'UserData');
   my_T = get(my_nyblom.obs,'UserData');
   my_const_model = get(my_nyblom.displaymenu,'UserData');
   if my_const_model(1)==1;
      this_mod = '(no constant)';
   elseif my_const_model(2)==1;
      this_mod = '(restricted constant)';
   elseif my_const_model(3)==1;
      this_mod = '(constant)';
   elseif my_const_model(4)==1;
      this_mod = '(restricted trend)';
   elseif my_const_model(5)==1;
      this_mod = '(trend)';
   end;
   cell_value = get(my_nyblom.cells,'Value');
   cell_vec = [20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100];
   numcells = cell_vec(cell_value);
   my_50 = floor(0.5*rep);
   my_80 = floor(0.8*rep);
   my_90 = floor(0.9*rep);
   my_95 = floor(0.95*rep);
   my_975 = floor(0.98*rep);
   my_99 = floor(0.99*rep);
   %
   % The max test
   %
   thisplot = figure('Units','pixels', ...
      'Position',[(tm.realscrsz(3)-600)/2 (tm.realscrsz(4)-400)/2 600 400], ...
      'Menubar','none', ...
      'Toolbar','none', ...
      'NumberTitle','off', ...
      'Visible','off', ...
      'Name','Density for Nyblom Max Test');
   %
   % obey centering and filling defaults
   %
   setfigureproperties(thisplot);
   %
   [n1,n2] = hist(NyblomMax,numcells);
   n1 = n1/rep;
   ylabelstr = 'Frequency';
   leg_pos = 1;
   cdf_value = get(my_nyblom.cdf,'Value');
   if (gcbo==my_nyblom.histogram)|(gcbo==my_nyblom.histogrammenu);
      if cdf_value==1;
         n1 = cumsum(n1);
         set(thisplot,'Name','Distribution for Nyblom Max Test');
      end;
      %
      n3 = bar(n2,n1,0.75);
      if curr_ini.colors==1;
         set(n3,'FaceColor',[0 0 0.8],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
      else;
         set(n3,'FaceColor',[0.5 0.5 0.5],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
      end;
      myleg = [];
      if cdf_value==1;
         set(gca,'YLim',[0 1.1],'XLim',[0 max(n2)+n2(1,2)-n2(1,1)]);
      end;
   else;
      ylabelstr = 'Density';
      if curr_ini.colors==1;
         c_vec_1 = [0 0 1];
         c_vec_2 = [1 0 0];
         c_vec_3 = [0 0.75 0];
         c_vec_4 = [1 0.5 0];
         c_vec_5 = [0 0.75 0.75];
         c_vec_6 = [0 0 0];
         c_vec_7 = [0 1 0];
      else;
         c_vec_1 = [0 0 0];
         c_vec_2 = [0.7 0.7 0.7];
         c_vec_3 = [0.6 0.6 0.6];
         c_vec_4 = [0.5 0.5 0.5];
         c_vec_5 = [0.4 0.4 0.4];
         c_vec_6 = [0.3 0.3 0.3];
         c_vec_7 = [0.2 0.2 0.2];
      end;
      %
      if (strcmp(tm.interpolate,'nearest')==1)|(strcmp(tm.interpolate,'linear')==1)|(strcmp(tm.interpolate,'spline')==1)|(strcmp(tm.interpolate,'cubic')==1);
         x_v = [];
         xsep = (n2(2)-n2(1))/100;
         for i=1:size(n2,2);
            x_v = [x_v n2(i)];
            if i<size(n2,2);
               for j=1:99;
                  x_v = [x_v (n2(i)+(j*xsep))];
               end;
            end;
         end;
         x_v = sort(x_v);
         n3 = interp1(n2,n1,x_v,tm.interpolate);
         cdf_n3 = cdf(x_v,n3);
         n3 = (1/max(cdf_n3))*n3;
      else;
         xmin = min(NyblomMax);
         xmax = max(NyblomMax);
         xrange = xmax-xmin;
         ax = xmin-xrange/4;
         bx = xmax+xrange/4;
         if strcmp(tm.interpolate,'knorm')==1;
            h = 0;
         else;
            h = hns(NyblomMax,tm.interpolate);
         end;
         if get(my_nyblom.adaptive,'Value')==1;
            [x_v,xa,n3,h,hl] = kdadapt(NyblomMax,tm.interpolate,512,h);
         else;
            [x_v,n3] = kdfft1(NyblomMax,tm.interpolate,512,h,0,[ax,bx]);
         end;
      end;
      if cdf_value==1;
         ylabelstr = 'Frequency';
         leg_pos = 4;
         n3 = cdf(x_v,n3);
         set(thisplot,'Name','Distribution for Nyblom Max Test');
      end;
      %
      plot(x_v,n3,'LineWidth',1,'Color',c_vec_1,'Tag',['max-dist-' num2str(my_n) '-' num2str(my_r)]);
      y_lim = [0 max(n3)+(0.1*max(n3))];
      set(gca,'YLim',y_lim);
      set(gca,'XLim',[0 max(x_v)]);
      hold('on');
      plot(NyblomMax(my_50)*ones(1,2),y_lim,'Color',c_vec_7,'LineStyle','-','LineWidth',1);
      hold('on');
      plot(NyblomMax(my_80)*ones(1,2),y_lim,'Color',c_vec_2,'LineStyle',':','LineWidth',1);
      hold('on');
      plot(NyblomMax(my_90)*ones(1,2),y_lim,'Color',c_vec_3,'LineStyle','-.','LineWidth',1);
      hold('on');
      plot(NyblomMax(my_95)*ones(1,2),y_lim,'Color',c_vec_4,'LineStyle','-','LineWidth',1);
      hold('on');
      plot(NyblomMax(my_975)*ones(1,2),y_lim,'Color',c_vec_5,'LineStyle','-.','LineWidth',1);
      hold('on');
      plot(NyblomMax(my_99)*ones(1,2),y_lim,'Color',c_vec_6,'LineStyle',':','LineWidth',1);
      hold('off');
      myleg = legend_fcn(ylabelstr,'50%','80%','90%','95%','98%','99%',leg_pos);
   end;
   setaxesfonts('Title',['Nyblom supremum test ' this_mod ' with ' num2str(my_n) ' variables and ' num2str(my_r) ' cointegration vectors'],'XLabel','Value','YLabel',ylabelstr);
   if isempty(myleg)==0;
      setaxesfonts(myleg);
      myleg = update_legend(myleg);
   end;
   set(gca,'UserData',myleg);
   toolbar_fcn(gca);
   hold('off');
   %
   % mean test
   %
   nextplot = figure('Units','pixels', ...
      'Position',[((tm.realscrsz(3)-600)/2)+22 ((tm.realscrsz(4)-400)/2)-22 600 400], ...
      'Menubar','none', ...
      'Toolbar','none', ...
      'NumberTitle','off', ...
      'Visible','off', ...
      'Name','Density for Nyblom Mean Test');
   %
   % obey centering and filling defaults
   %
   setfigureproperties(nextplot);
   %
   [n1,n2] = hist(NyblomMean,numcells);
   n1 = n1/rep;
   if (gcbo==my_nyblom.histogram)|(gcbo==my_nyblom.histogrammenu);
      if cdf_value==1;
         n1 = cumsum(n1);
         set(nextplot,'Name','Distribution for Nyblom Mean Test');
      end;
      n3 = bar(n2,n1,0.75);
      if curr_ini.colors==1;
         set(n3,'FaceColor',[0 0 0.8],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
      else;
         set(n3,'FaceColor',[0.5 0.5 0.5],'EdgeColor','k','LineWidth',1,'Tag','autopatch');
      end;
      myleg = [];
      if cdf_value==1;
         set(gca,'YLim',[0 1.1],'XLim',[0 max(n2)+n2(1,2)-n2(1,1)]);
      end;
   else;
      if (strcmp(tm.interpolate,'nearest')==1)|(strcmp(tm.interpolate,'linear')==1)|(strcmp(tm.interpolate,'spline')==1)|(strcmp(tm.interpolate,'cubic')==1);
         x_v = [];
         xsep = (n2(2)-n2(1))/100;
         for i=1:size(n2,2);
            x_v = [x_v n2(i)];
            if i<size(n2,2);
               for j=1:99;
                  x_v = [x_v (n2(i)+(j*xsep))];
               end;
            end;
         end;
         x_v = sort(x_v);
         n3 = interp1(n2,n1,x_v,tm.interpolate);
         cdf_n3 = cdf(x_v,n3);
         n3 = (1/max(cdf_n3))*n3;
      else;
         xmin = min(NyblomMean);
         xmax = max(NyblomMean);
         xrange = xmax-xmin;
         ax = xmin-xrange/4;
         bx = xmax+xrange/4;
         if strcmp(tm.interpolate,'knorm')==1;
            h = 0;
         else;
            h = hns(NyblomMean,tm.interpolate);
         end;
         if get(my_nyblom.adaptive,'Value')==1;
            [x_v,xa,n3,h,hl] = kdadapt(NyblomMean,tm.interpolate,512,h);
         else;
            [x_v,n3] = kdfft1(NyblomMean,tm.interpolate,512,h,0,[ax,bx]);
         end;
      end;
      if cdf_value==1;
         n3 = cdf(x_v,n3);
         set(nextplot,'Name','Distribution for Nyblom Mean Test');
      end;
      %
      plot(x_v,n3,'LineWidth',1,'Color',c_vec_1,'Tag',['mean-dist-' num2str(my_n) '-' num2str(my_r)]);
      y_lim = [0 max(n3)+(0.1*max(n3))];
      set(gca,'YLim',y_lim);
      set(gca,'XLim',[0 max(x_v)]);
      hold('on');
      plot(NyblomMean(my_50)*ones(1,2),y_lim,'Color',c_vec_7,'LineStyle','-','LineWidth',1);
      hold('on');
      plot(NyblomMean(my_80)*ones(1,2),y_lim,'Color',c_vec_2,'LineStyle',':','LineWidth',1);
      hold('on');
      plot(NyblomMean(my_90)*ones(1,2),y_lim,'Color',c_vec_3,'LineStyle','-.','LineWidth',1);
      hold('on');
      plot(NyblomMean(my_95)*ones(1,2),y_lim,'Color',c_vec_4,'LineStyle','-','LineWidth',1);
      hold('on');
      plot(NyblomMean(my_975)*ones(1,2),y_lim,'Color',c_vec_5,'LineStyle','-.','LineWidth',1);
      hold('on');
      plot(NyblomMean(my_99)*ones(1,2),y_lim,'Color',c_vec_6,'LineStyle',':','LineWidth',1);
      hold('off');
      myleg = legend_fcn(ylabelstr,'50%','80%','90%','95%','98%','99%',leg_pos);
   end;
   setaxesfonts('Title',['Nyblom mean test ' this_mod ' with ' num2str(my_n) ' variables and ' num2str(my_r) ' cointegration vectors'],'XLabel','Value','YLabel',ylabelstr);
   if isempty(myleg)==0;
      setaxesfonts(myleg);
      myleg = update_legend(myleg);
   end;
   set(gca,'UserData',myleg);
   toolbar_fcn(gca);
   hold('off');
   if curr_ini.external==0;
      set(thisplot,'Visible','on');
      set(nextplot,'Visible','on');
   else;
      this_mod = strrep(this_mod,'(','');
      this_mod = strrep(this_mod,')','');
      this_mod = strtrim(this_mod);
      this_mod = strrep(this_mod,' ','.');
      if (gcbo==my_nyblom.histogram)|(gcbo==my_nyblom.histogrammenu);
         file1 = [curr_ini.simulatedir 'nyblom-hist-max-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         file2 = [curr_ini.simulatedir 'nyblom-hist-mean-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
      else;
         file1 = [curr_ini.simulatedir 'nyblom-max-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
         file2 = [curr_ini.simulatedir 'nyblom-mean-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-' this_mod];
      end;
      mstat1 = autosavefigure(thisplot,file1);
      mstat2 = autosavefigure(nextplot,file2);
      if mstat1==0;
         autoshowfigure(file1);
      end;
      if mstat2==0;
         autoshowfigure(file2);
      end;
   end;
   set(nyblom_gui,'UserData',my_nyblom);
   %
   % case simulate
   %
case 'simulate'
   tm.nyblom_run = 1;
   set(nyblom_gui,'Visible','off');
   drawnow;
   %
   % collect values
   %
   my_T = 100*get(my_nyblom.obs,'Value');
   repvalues = [100 1000 2000 3000 4000 5000 10000 20000 30000 40000 50000 100000 200000 300000 400000 500000 1000000];
   rep_val = get(my_nyblom.rep,'Value');
   rep = repvalues(rep_val);
   set(my_nyblom.simulate,'UserData',rep);
   my_n = get(my_nyblom.my_n,'Value')+1;
   my_r = get(my_nyblom.my_r,'Value');
   if my_n>my_r;
      %
      % initialize and compute original statistics
      %
      same_deter = 0;
      
      if ((tm.deterselect(1,1)==1)&(tm.const_model(3)==1))|((tm.deterselect(1,2)==1)&(tm.const_model(2)==1))|((tm.deterselect(1,3)==1)&(tm.const_model(5)==1))|((tm.deterselect(1,4)==1)&(tm.const_model(4)==1));
         same_deter = 1;
      end;
      if (my_n==tm.n)&(same_deter==1);
         if curr_ini.fullrec==1;
            [nyblomT,nyblomcorr,evaluet] = boot_nyblom_partial(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.T);
         else;
            [nyblomT,nyblomcorr,evaluet] = boot_nyblom_full(tm.Z0,tm.Z1,tm.Z2,my_r,tm.p,tm.q1,tm.d,curr_ini.T0,tm.df,tm.deterselect,tm.T);
         end;
         tm.NyblomMean = (1/size(nyblomT,2))*sum(nyblomT);
         tm.NyblomMax = max(nyblomT);
      end;
      %
      n_r = my_n-my_r;
      NyblomMean = [];
      NyblomMax = [];
      abort = '';
      draw = 1;
      showprog = get(my_nyblom.progress,'Value');
      if showprog==1;
         input_var.title = ['Progress for ' int2str(rep) ' replications'];
         input_var.facecolor = curr_ini.progress_facecolor;
         input_var.startfacecolor = curr_ini.progress_startfacecolor;
         input_var.edgecolor = curr_ini.progress_edgecolor;
         input_var.bgcolor = curr_ini.progress_bgcolor;
         input_var.clock = get(my_nyblom.clock,'Value');
         input_var.label = 'Replication number:';
         input_var.stop = 0;
         mywait = progressdlg(0,input_var);
         set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
      else;
         this_text = strvcat('Resistence is futile. You will be assimulated...',' ',['Time: ' datestr(now,14)],' ','Please hold!');
         mywait = waitdlg(this_text,'borg','Nyblom Simulation');
         waitf = get(mywait,'UserData');
         tic;
      end;
      if tm.const_model(1)==1;
         if showprog==1;
            set(mywait,'Name',['Replications for Model 1 with ' num2str(my_T,'%0.0f') ' draws']);
            drawnow;
         end;
         while (draw<=rep);
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            S = zeros(n_r,my_r);
            M = zeros(n_r,n_r);
            Q = 0;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            Epr = randn(n_r+my_r,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Er = Epr(n_r+1:(n_r+my_r),:);
            Epr = Epr(1:n_r,:);
            B = cumsum(Epr,2);
            for t=2:my_T;
               S = [S (S(:,size(S,2)-my_r+1:size(S,2)) + (B(:,t-1)*Er(:,t)') )];
               M = [M (M(:,size(M,2)-n_r+1:size(M,2)) + (B(:,t-1)*B(:,t-1)') )];
            end;
            iMT = M(:,size(M,2)-n_r+1:size(M,2))\eye(n_r);
            iMT_ST = iMT*S(:,size(S,2)-my_r+1:size(S,2));
            for t=2:my_T;
               S_star = S(:,((t-1)*my_r)+1:t*my_r)-(M(:,((t-1)*n_r)+1:t*n_r)*iMT_ST);
               Q = [Q sum(diag(S_star'*iMT*S_star))];
            end;
            new_NyblomMean = sum(Q)/my_T;
            new_NyblomMax = max(Q);
            NyblomMean = [NyblomMean;new_NyblomMean];
            NyblomMax = [NyblomMax;new_NyblomMax];
            draw = draw+1;
         end;
      elseif tm.const_model(2)==1;
         setlogtext(strvcat(' ','Simulating distribution for Nyblom tests...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted constant',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         nyblomMean = zeros(rep,1);
         nyblomMax = zeros(rep,1);
         while (draw<=rep);
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            Bbar = zeros(n_r+1,1);
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            Epr = randn(n_r+my_r,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Er = Epr(n_r+1:(n_r+my_r),:);
            Epr = Epr(1:n_r,:);
            Epr = [Epr;[1 zeros(1,my_T-1)]];
            B = cumsum(Epr,2);
            S = zeros(n_r+1,my_r*my_T);
            M = zeros(n_r+1,(n_r+1)*my_T);
            for t=2:my_T;
               S(:,my_r*(t-1)+1:my_r*t) = S(:,my_r*(t-2)+1:my_r*(t-1)) + (B(:,t-1)*Er(:,t)');
               M(:,(n_r+1)*(t-1)+1:(n_r+1)*t) = M(:,(n_r+1)*(t-2)+1:(n_r+1)*(t-1)) + (B(:,t-1)*B(:,t-1)');
            end;
            iMT = M(:,size(M,2)-n_r:size(M,2))\eye(n_r+1);
            iMT_ST = iMT*S(:,size(S,2)-my_r+1:size(S,2));
            Q = zeros(1,my_T);
            for t=2:my_T;
               S_star = S(:,((t-1)*my_r)+1:t*my_r)-(M(:,((t-1)*(n_r+1))+1:t*(n_r+1))*iMT_ST);
               Q(1,t) = sum(diag(S_star'*iMT*S_star));
            end;
            NyblomMean(draw,1) = sum(Q)/my_T;
            NyblomMax(draw,1) = max(Q);
            draw = draw+1;
         end;
      elseif tm.const_model(3)==1;
         setlogtext(strvcat(' ','Simulating distribution for Nyblom tests...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Unrestricted constant',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Constant model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         nyblomMean = zeros(rep,1);
         nyblomMax = zeros(rep,1);
         while (draw<=rep);
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            Epr = randn(n_r+my_r,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Er = Epr(n_r+1:(n_r+my_r),:);
            Epr = Epr(1:n_r-1,:);
            B = cumsum(Epr,2);
            Bbar = (1/my_T)*sum(B,2);
            B = B-(Bbar*ones(1,my_T));
            B = [B;(1:1:my_T)-((my_T+1)/2)];
            S = zeros(n_r,my_r*my_T);
            M = zeros(n_r,n_r*my_T);
            for t=2:my_T;
               S(:,my_r*(t-1)+1:my_r*t) = S(:,my_r*(t-2)+1:my_r*(t-1)) + (B(:,t-1)*Er(:,t)');
               M(:,n_r*(t-1)+1:n_r*t) = M(:,n_r*(t-2)+1:n_r*(t-1)) + (B(:,t-1)*B(:,t-1)');
            end;
            iMT = M(:,size(M,2)-n_r+1:size(M,2))\eye(n_r);
            iMT_ST = iMT*S(:,size(S,2)-my_r+1:size(S,2));
            Q = zeros(1,my_T);
            for t=2:my_T;
               S_star = S(:,((t-1)*my_r)+1:t*my_r)-(M(:,((t-1)*n_r)+1:t*n_r)*iMT_ST);
               Q(1,t) = sum(diag(S_star'*iMT*S_star));
            end;
            NyblomMean(draw,1) = sum(Q)/my_T;
            NyblomMax(draw,1) = max(Q);
            draw = draw+1;
         end;
      elseif tm.const_model(4)==1;
         setlogtext(strvcat(' ','Simulating distribution for Nyblom tests...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Restricted linear trend',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Restricted trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         nyblomMean = zeros(rep,1);
         nyblomMax = zeros(rep,1);
         while (draw<=rep);
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            Epr = randn(n_r+my_r,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Er = Epr(n_r+1:(n_r+my_r),:);
            Epr = Epr(1:n_r,:);
            B = cumsum(Epr,2);
            Bbar = (1/my_T)*sum(B,2);
            B = B-(Bbar*ones(1,my_T));
            B = [B;(1:1:my_T)-((my_T+1)/2)];
            S = zeros(n_r+1,my_r*my_T);
            M = zeros(n_r+1,(n_r+1)*my_T);
            for t=2:my_T;
               S(:,my_r*(t-1)+1:my_r*t) = S(:,my_r*(t-2)+1:my_r*(t-1)) + (B(:,t-1)*Er(:,t)');
               M(:,(n_r+1)*(t-1)+1:(n_r+1)*t) = M(:,(n_r+1)*(t-2)+1:(n_r+1)*(t-1)) + (B(:,t-1)*B(:,t-1)');
            end;
            iMT = M(:,size(M,2)-n_r:size(M,2))\eye(n_r+1);
            iMT_ST = iMT*S(:,size(S,2)-my_r+1:size(S,2));
            Q = zeros(1,my_T);
            for t=2:my_T;
               S_star = S(:,((t-1)*my_r)+1:t*my_r)-(M(:,((t-1)*(n_r+1))+1:t*(n_r+1))*iMT_ST);
               Q(1,t) = sum(diag(S_star'*iMT*S_star));
            end;
            NyblomMean(draw,1) = sum(Q)/my_T;
            NyblomMax(draw,1) = max(Q);
            draw = draw+1;
         end;
      elseif tm.const_model(5)==1;
         setlogtext(strvcat(' ','Simulating distribution for Nyblom tests...',['Simulation started at: ' datestr(now,14) '...'],'Model:','       Linear trend',['       ' num2str(my_n) ' endogenous variables'],['       ' num2str(my_r) ' cointegration relations'],['       ' num2str(my_T) ' observations'],['       ' num2str(rep) ' replications']));
         if showprog==1;
            set(mywait,'Name',['Linear trend model with ' num2str(my_T,'%0.0f') ' obs']);
            drawnow;
         end;
         my_t = (1:1:my_T);
         my_t2 = my_t.*my_t;
         x_mat = [ones(1,my_T);my_t];
         x_mat2 = x_mat*x_mat';
         inv_xmat2 = x_mat2\eye(2);
         nyblomMean = zeros(rep,1);
         nyblomMax = zeros(rep,1);
         while (draw<=rep);
            if showprog==1;
               abort = get(mywait,'UserData');
               if strcmp(abort,'cancel')==1;
                  break;
               else;
                  progressdlg([(draw/rep) draw]);
               end;
            end;
            %
            % reset the random number generator
            %
            if curr_ini.random_state==2;
               randn('state',draw);
            elseif curr_ini.random_state==3;
               randn('state',sum(100*clock));
            elseif curr_ini.random_state==4;
               randn('state',sum(100*clock)+draw);
            end;
            Epr = randn(n_r+my_r,my_T+50);
            Epr = Epr(:,51:my_T+50);
            %
            % make sure draws in Epr have identity covariance matrix
            %
            Sig = (1/my_T)*Epr*Epr';
            P_sig = chol(Sig)';
            Epr = P_sig\Epr;
            Er = Epr(n_r+1:(n_r+my_r),:);
            Epr = Epr(1:n_r-1,:);
            B = [cumsum(Epr,2);my_t2];
            %
            % make correction B by (1,t)
            %
            B = B-(B*x_mat'*inv_xmat2*x_mat);
            S = zeros(n_r,my_r*my_T);
            M = zeros(n_r,n_r*my_T);
            for t=2:my_T;
               S(:,my_r*(t-1)+1:my_r*t) = S(:,my_r*(t-2)+1:my_r*(t-1)) + (B(:,t-1)*Er(:,t)');
               M(:,n_r*(t-1)+1:n_r*t) = M(:,n_r*(t-2)+1:n_r*(t-1)) + (B(:,t-1)*B(:,t-1)');
            end;
            iMT = M(:,size(M,2)-n_r+1:size(M,2))\eye(n_r);
            iMT_ST = iMT*S(:,size(S,2)-my_r+1:size(S,2));
            Q = zeros(1,my_T);
            for t=2:my_T;
               S_star = S(:,((t-1)*my_r)+1:t*my_r)-(M(:,((t-1)*n_r)+1:t*n_r)*iMT_ST);
               Q(1,t) = sum(diag(S_star'*iMT*S_star));
            end;
            NyblomMean(draw,1) = sum(Q)/my_T;
            NyblomMax(draw,1) = max(Q);
            draw = draw+1;
         end;
      end;
      if showprog==1;
         set(mywait,'UserData','done');
         close(mywait);
         drawnow;
      else;
         set(waitf.text,'UserData','done');
         delete(mywait);
         drawnow;
         new_time = toc;
         my_hrs = '00';
         my_min = '00';
         my_sec = num2str(new_time,'%0.2f');
         if new_time>=60;
            ch_min = floor(new_time/60);
            my_sec = num2str(new_time-(ch_min*60),'%0.2f');
            my_min = num2str(ch_min,'%0.0f');
            if ch_min>=60;
               ch_hrs = floor(ch_min/60);
               my_min = num2str(ch_min-(ch_hrs*60),'%0.0f');
               my_hrs = num2str(ch_hrs,'%0.0f');
            end;
         end;
         if size(my_sec,2)==4;
            my_sec = ['0' my_sec];
         end;
         if size(my_min,2)==1;
            my_min = ['0' my_min];
         end;
         if size(my_hrs,2)==1;
            my_hrs = ['0' my_hrs];
         end;
         clock_str = [my_hrs ':' my_min ':' my_sec];
         this_text = strvcat('The assimulation process took:',' ',['    ' clock_str ' (hrs:min:sec)']);
         about(this_text,'borg','Simulation Time',120,350);
      end;
      %
      % if we don't cancel
      %
      if (strcmp(abort,'cancel')==0)&(isempty(NyblomMax)==0);
         setlogtext(['Simulation completed at: ' datestr(now,14) '!']);
         NyblomMean = sort(NyblomMean);
         NyblomMax = sort(NyblomMax);
         new_quantiles = ceil(rep*quantiles_fcn);
         cv_mean = NyblomMean(new_quantiles);
         cv_max = NyblomMax(new_quantiles);
         quantiles = [];
         for i=50:99;
            quantiles = [quantiles;ceil((i/100)*rep)];
         end;
         quant_mean = NyblomMean(quantiles);
         quant_max = NyblomMax(quantiles);
         %
         % Computing p-values
         %
         boot_pval = [];
         if (my_n==tm.n)&(same_deter==1);
            setlogtext('Determining the asymptotic p-value of the Nyblom tests...');
            for j=1:rep;
               if tm.NyblomMean>=NyblomMean(rep+1-j,1);
                  break;
               end;
            end;
            boot_pval = j/rep;
            for j=1:rep;
               if tm.NyblomMax>=NyblomMax(rep+1-j,1);
                  break;
               end;
            end;
            boot_pval = [boot_pval j/rep];
         end;
         %
         set(my_nyblom.rep,'UserData',rep);
         set(my_nyblom.obs,'UserData',my_T);
         set(my_nyblom.my_n,'UserData',my_n);
         set(my_nyblom.my_r,'UserData',my_r);
         set(my_nyblom.displaymenu,'Enable','on','UserData',tm.const_model);
         if tm.const_model(1)==1;
            file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
            file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
            file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
            file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_noconst.m'];
            my_mod = 'No constant';
         elseif tm.const_model(2)==1;
            file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
            file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
            file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
            file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_resconst.m'];
            my_mod = 'Restricted constant';
         elseif tm.const_model(3)==1;
            file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_const.m'];
            file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_const.m'];
            file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_const.m'];
            file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_const.m'];
            my_mod = 'Constant';
         elseif tm.const_model(4)==1;
            file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
            file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
            file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
            file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_restrend.m'];
            my_mod = 'Restricted linear trend';
         elseif tm.const_model(5)==1;
            file_mean = [curr_ini.simulatedir 'nyblom_mean_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
            file_max = [curr_ini.simulatedir 'nyblom_max_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
            file_qmean = [curr_ini.simulatedir 'nyblom_quantile_mean_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
            file_qmax = [curr_ini.simulatedir 'nyblom_quantile_max_' num2str(my_n) '_' num2str(my_r) '_trend.m'];
            my_mod = 'Linear trend';
         end;
         if get(my_nyblom.mfile,'Value')==1;
            setlogtext('Saving results to m-files...');
            fid_mean = fopen(file_mean,'wt');
            fid_max = fopen(file_max,'wt');
            fprintf(fid_mean,['function out = ' getname(file_mean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
            fprintf(fid_max,['function out = ' getname(file_max) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
            for j=1:size(cv_max,1);
               if j==1;
                  fprintf(fid_mean,['out = [ ' num2str(cv_mean(1,1),'%1.12f') ';\n']);
                  fprintf(fid_max,['out = [ ' num2str(cv_max(1,1),'%1.12f') ';\n']);
               elseif j==size(cv_max,1);
                  fprintf(fid_mean,['        ' num2str(cv_mean(j,1),'%1.12f') '];\n\n']);
                  fprintf(fid_max,['        ' num2str(cv_max(j,1),'%1.12f') '];\n\n']);
               else;
                  fprintf(fid_mean,['        ' num2str(cv_mean(j,1),'%1.12f') ';\n']);
                  fprintf(fid_max,['        ' num2str(cv_max(j,1),'%1.12f') ';\n']);
               end;
            end;
            mean_text = ['%%\n%% end of ' getfilename(file_mean) '\n%%\n'];
            fprintf(fid_mean,mean_text);
            fclose(fid_mean);
            max_text = ['%%\n%% end of ' getfilename(file_max) '\n%%\n'];
            fprintf(fid_max,max_text);
            fclose(fid_max);
            fid_qmean = fopen(file_qmean,'wt');
            fid_qmax = fopen(file_qmax,'wt');
            fprintf(fid_qmean,['function out = ' getname(file_qmean) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
            fprintf(fid_qmax,['function out = ' getname(file_qmax) '\n\n%%\n%% Number of replications: ' num2str(rep) '\n%% Number of draws: ' num2str(my_T) '\n%%\n\n']);
            for j=1:size(quant_max,1);
               if j==1;
                  fprintf(fid_qmean,['out = [ ' num2str(quant_mean(1,1),'%1.12f') ';\n']);
                  fprintf(fid_qmax,['out = [ ' num2str(quant_max(1,1),'%1.12f') ';\n']);
               elseif j==size(quant_max,1);
                  fprintf(fid_qmean,['        ' num2str(quant_mean(j,1),'%1.12f') '];\n\n']);
                  fprintf(fid_qmax,['        ' num2str(quant_max(j,1),'%1.12f') '];\n\n']);
               else;
                  fprintf(fid_qmean,['        ' num2str(quant_mean(j,1),'%1.12f') ';\n']);
                  fprintf(fid_qmax,['        ' num2str(quant_max(j,1),'%1.12f') ';\n']);
               end;
            end;
            mean_text = ['%%\n%% end of ' getfilename(file_qmean) '\n%%\n'];
            fprintf(fid_qmean,mean_text);
            fclose(fid_qmean);
            max_text = ['%%\n%% end of ' getfilename(file_qmax) '\n%%\n'];
            fprintf(fid_qmax,max_text);
            fclose(fid_qmax);
         end;
         %
         % save full simulations
         %
         if get(my_nyblom.save,'Value')==1;
            setlogtext('Saving results to mat-files...');
            if tm.const_model(1)==1;
               full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.mat'];
            elseif tm.const_model(2)==1;
               full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.mat'];
            elseif tm.const_model(3)==1;
               full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.mat'];
            elseif tm.const_model(4)==1;
               full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.mat'];
            elseif tm.const_model(5)==1;
               full_mat = [curr_ini.simulatedir 'nyblom-full-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.mat'];
            end;
            Number = (1:1:rep)';
            save(full_mat,'Number','NyblomMax','NyblomMean');
            set(my_nyblom.fullmenu,'Enable','on','UserData',full_mat);
            set(my_nyblom.full,'Enable','on');
         end;
         setlogtext('Saving simulation summary to text file...');
         %
         % write summary to file
         %
         sp_str = spacestr(curr_ini.decimals-2);
         prt_val = ['%' num2str(6+curr_ini.decimals,'%0.0f') '.' num2str(curr_ini.decimals,'%0.0f') 'f'];
         my_50 = floor(0.5*rep);
         my_80 = floor(0.8*rep);
         my_90 = floor(0.9*rep);
         my_95 = floor(0.95*rep);
         my_975 = floor(0.98*rep);
         my_99 = floor(0.99*rep);
         res_str = strvcat(' ','**************************************************************','*                          Results                           *');
         res_str = strvcat(res_str,'**************************************************************',' ',['  Model:                   ' my_mod],['  Endogenous variables:    ' num2str(my_n,'%0.0f')],['  Cointegration relations: ' num2str(my_r,'%0.0f')],['  Replications:            ' num2str(rep,'%0.0f')],['  Draws per replication:   ' num2str(my_T,'%0.0f')],' ');
         res_str = strvcat(res_str,'                           Max test','                           --------',' ',['    50%   ' sp_str '    80%   ' sp_str '    90%    ' sp_str '   95%   ' sp_str '    98%    ' sp_str '   99%   ' sp_str '    Mean ' sp_str '  Std. Dev.']);
         max_std = sqrt( (1/rep)*sum( ( NyblomMax - ( (1/rep)*sum(NyblomMax) ) ).*( NyblomMax - ( (1/rep)*sum(NyblomMax) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],NyblomMax(my_50),NyblomMax(my_80),NyblomMax(my_90),NyblomMax(my_95),NyblomMax(my_975),NyblomMax(my_99),(1/rep)*sum(NyblomMax),max_std),' ');
         %
         res_str = strvcat(res_str,'                           Mean test','                           ---------',' ',['    50%   ' sp_str '    80%   ' sp_str '    90%    ' sp_str '   95%   ' sp_str '    98%    ' sp_str '   99%   ' sp_str '    Mean ' sp_str '  Std. Dev.']);
         mean_std = sqrt( (1/rep)*sum( ( NyblomMean - ( (1/rep)*sum(NyblomMean) ) ).*( NyblomMean - ( (1/rep)*sum(NyblomMean) ) ) ) );
         res_str = strvcat(res_str,sprintf([prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val '  ' prt_val],NyblomMean(my_50),NyblomMean(my_80),NyblomMean(my_90),NyblomMean(my_95),NyblomMean(my_975),NyblomMean(my_99),(1/rep)*sum(NyblomMean),mean_std),' ');
         if (my_n==tm.n)&(same_deter==1);
            res_str = strvcat(res_str,'                      Asymptotic p-values','                      -------------------',' ');
            res_str = strvcat(res_str,sprintf([' sup Q(t|T) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],tm.NyblomMax,boot_pval(1,2)));
            res_str = strvcat(res_str,sprintf(['mean Q(t|T) = ' prt_val ',  p-value = %0.' num2str(curr_ini.decimals,'%0.0f') 'f'],tm.NyblomMean,boot_pval(1,1)),' ');
         end;
         res_str = strvcat(res_str,'**************************************************************',' ');
         %
         if tm.const_model(1)==1;
            file_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-noconst.txt'];
         elseif tm.const_model(2)==1;
            file_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-resconst.txt'];
         elseif tm.const_model(3)==1;
            file_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-const.txt'];
         elseif tm.const_model(4)==1;
            file_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-restrend.txt'];
         elseif tm.const_model(5)==1;
            file_txt = [curr_ini.simulatedir 'nyblom-summary-' num2str(my_n) '.' num2str(my_r) '-' num2str(my_T) '.' num2str(rep) '-trend.txt'];
         end;
         fid_txt = fopen(file_txt,'wt');
         for i=1:size(res_str,1);
            fprintf(fid_txt,[strrep(res_str(i,:),'%','%%') '\n']);
         end;
         fprintf(fid_txt,['Output created on: ' datestr(now,0) '\n']);
         fclose(fid_txt);
         if curr_ini.noprint==0;
            set(my_nyblom.output,'Enable','on');
         end;
         set(my_nyblom.summarymenu,'Enable','on','UserData',file_txt);
         set(my_nyblom.summary,'Enable','on');
         set(my_nyblom.display,'Enable','on','UserData',[NyblomMax NyblomMean]);
         set(my_nyblom.histogram,'Enable','on');
         set(my_nyblom.histogrammenu,'Enable','on');
         set(my_nyblom.mfilebutton,'Enable','on');
         set(my_nyblom.mfilemenu,'Enable','on');
         set(my_nyblom.matfilebutton,'Enable','on');
         set(my_nyblom.matfilemenu,'Enable','on');
      else;
         setlogtext('Cancelled...');
      end;
   else;
      mytext = 'You must select fewer cointegration relations than variables.';
      about(mytext,'error','Illegal parameters...',120,350);
      if tm.r<tm.n;
         set(my_nyblom.my_r,'Value',tm.r);
      else;
         set(my_nyblom.my_r,'Value',1);
      end;
   end;
   tm.nyblom_run = 0;
   set(nyblom_gui,'Visible','on');
case 'done'
   if tm.nyblom_run==0;
      set(my_nyblom.done,'UserData','done');
      pid = get(my_nyblom.filemenu,'UserData');
      if isempty(pid)==1;
         delete(nyblom_gui);
      else;
         close(nyblom_gui);
      end;
   end;
end;

if strcmp(selector,'init')==1;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(nyblom_gui,'Name') ' ' fix_filepath([pwd '\icons\simulate.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(my_nyblom.filemenu,'UserData',pid);
         set(nyblom_gui,'CloseRequestFcn','killwinpid');
      end;
   end;
   set(nyblom_gui,'Visible','on');
end;

if strcmp(selector,'done')==0;
   curr_ini.models = tm;
   curr_ini.images = button_images;
   set(my_nyblom.mfilebutton,'UserData',curr_ini);
end;

if my_exit==1;
   waitfor(my_nyblom.done,'UserData','done');
end;

%
% end of nyblom_dist.m
%
