%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab GUI dialog for reordering a list               %
%                                                                %
%          Function: reorder_fcn                                 %
%                                                                %
%          Input:                                                %
%                       selector: case switch function           %
%                       files: string matrix                     %
%                       name: figure title                       %
%                       axlist: axesbox title                    %
%                       axlength: width of axesbox title         %
%                                                                %
%          Output:                                               %
%                       h = handle                               %
%                                                                %
%          This version:        March 31, 2004                   %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h = reorder_fcn(selector,files,name,axlist,axlength)

if strcmp(selector,'init')==1;
   thisexit = 0;
   tm.strings = files;
   if size(tm.strings,1)>3;
      height = size(tm.strings,1)*18+94;
   else;
      height = (size(tm.strings,1)+2)*18+94;
   end;
   tm.oldstrings = tm.strings;
   %
   % button icons
   %
   mycons = getstoredimages;
   cu_ini = find_inisettings;
   if cu_ini.use_toolbar_bgcolor==1;
      bgcolor = (1/255)*(round(255*get(0,'defaultuicontrolbackgroundcolor'))-[8 4 8]);
      bgcolor(1) = max(0,bgcolor(1));
      bgcolor(2) = max(0,bgcolor(2));
      bgcolor(3) = max(0,bgcolor(3));
   else;
      bgcolor = get(0,'defaultuicontrolbackgroundcolor');
   end;
   myup = maketrans(mycons.up_image,[160 160 164],bgcolor);
   mydown = maketrans(mycons.down_image,[160 160 164],bgcolor);
   %
   % Set screen size directly instead of using
   % get(0,'ScreenSize')!
   %
   realscrsz = get(0,'ScreenSize');
   if height>realscrsz(4)-100;
      height = realscrsz(4)-100;
   elseif height<134;
      height = 152;
   end;
else;
   thisexit = 1;
   reordergui = findobj('Type','figure','Tag','ReorderFig')';
   reorder = get(reordergui,'UserData');
   tm = get(reorder.thisfile,'UserData');
end;

switch selector;
   case 'init';
      reordergui = figure('Color',get(0,'defaultuicontrolbackgroundcolor'), ...
         'FileName','reorder_fcn.m', ...
         'MenuBar','none', ...
         'PaperUnits','points', ...
         'Units','pixels', ...
         'Position',[(realscrsz(3)-512)/2 (realscrsz(4)-height)/2 512 height], ...
         'Tag','ReorderFig', ...
         'Resize','off', ...
         'Name',name, ...
         'NumberTitle','off', ...
         'Visible','off', ...
         'WindowStyle','modal', ...
         'CloseRequestFcn','reorder_fcn exit', ...
         'ToolBar','none');

      %
      % Outer axis
      %

      axesbox([2 2 510 height-14],axlist,axlength,[0.5 1]);

      %
      % Displaying the model files
      %

      reorder.thisfile = uicontrol('Units','pixels', ...
         'BackgroundColor',[1 1 1], ...
         'Position',[20 60 400 height-94], ...
         'FontSize',10, ...
         'Style','listbox', ...
         'Enable','on', ...
         'Max',1, ...
         'HorizontalAlignment','center', ...
         'String',tm.strings, ...
         'Tag','Text1',...
         'Value',1);

      %
      % Move models up and down
      %

      checkh = (realscrsz(4)-100)/2;

      reorder.up = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[442 min(size(tm.strings,1)*9+76,checkh+19) 50 22], ...
         'TooltipString','Move up', ...
         'CData',myup, ...
         'CallBack','reorder_fcn up', ...
         'Enable','on', ...
         'Tag','UpButton');


      reorder.icon = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[442 min(size(tm.strings,1)*9+50,checkh-7) 50 22], ...
         'TooltipString','Move down', ...
         'CData',mydown, ...
         'CallBack','reorder_fcn down', ...
         'Enable','on', ...
         'Tag','DownButton');

      %
      % OK, Cancel and Apply buttons
      %

      reorder.done = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[111 14 90 20], ...
         'String','OK', ...
         'FontSize',6, ...
         'CallBack','reorder_fcn done', ...
         'Enable','on', ...
         'UserData','waiting', ...
         'Tag','DoneButton');

      reorder.cancel = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[211 14 90 20], ...
         'String','Cancel', ...
         'FontSize',6, ...
         'CallBack','reorder_fcn cancel', ...
         'Enable','on', ...
         'UserData',files, ...
         'Tag','CancelButton');

      reorder.apply = uicontrol('Units','pixels', ...
         'BackgroundColor',get(0,'defaultuicontrolbackgroundcolor'), ...
         'Position',[311 14 90 20], ...
         'String','Apply', ...
         'FontSize',6, ...
         'CallBack','reorder_fcn apply', ...
         'Enable','off', ...
         'UserData','waiting', ...
         'Tag','ApplyButton');

      set(reordergui,'UserData',reorder,...
         'HandleVisibility','callback');

   case 'up';
      currval = get(reorder.thisfile,'Value');
      if currval>1;
         set(reorder.apply,'Enable','on');
         if currval==2;
            if size(tm.strings,1)>2;
               tm.strings = strvcat(tm.strings(2,:),tm.strings(1,:),tm.strings(3:size(tm.strings,1),:));
            else;
               tm.strings = strvcat(tm.strings(2,:),tm.strings(1,:));
            end;
         elseif currval==size(tm.strings,1);
            tm.strings = strvcat(tm.strings(1:currval-2,:),tm.strings(currval,:),tm.strings(currval-1,:));
         else;
            tm.strings = strvcat(tm.strings(1:currval-2,:),tm.strings(currval,:),tm.strings(currval-1,:),tm.strings(currval+1:size(tm.strings,1),:));
         end;
         set(reorder.thisfile,'String',tm.strings);
         set(reorder.thisfile,'Value',currval-1);
      end;
   case 'down';
      currval = get(reorder.thisfile,'Value');
      if currval<size(tm.strings,1);
         set(reorder.apply,'Enable','on');
         if currval==1;
            if size(tm.strings,1)>2;
               tm.strings = strvcat(tm.strings(2,:),tm.strings(1,:),tm.strings(3:size(tm.strings,1),:));
            else;
               tm.strings = strvcat(tm.strings(2,:),tm.strings(1,:));
            end;
         elseif currval==size(tm.strings,1)-1;
            tm.strings = strvcat(tm.strings(1:currval-1,:),tm.strings(currval+1,:),tm.strings(currval,:));
         else;
            tm.strings = strvcat(tm.strings(1:currval-1,:),tm.strings(currval+1,:),tm.strings(currval,:),tm.strings(currval+2:size(tm.strings,1),:));
         end;
         set(reorder.thisfile,'String',tm.strings);
         set(reorder.thisfile,'Value',currval+1);
      end;
   case 'cancel';
      tm.strings = tm.oldstrings;
      set(reorder.cancel,'UserData',tm.strings);
      set(reorder.thisfile,'String',tm.strings);
      set(reorder.thisfile,'Value',1);
      set(reorder.apply,'Enable','off');
      set(reordergui,'UserData',reorder);
%      reorder_fcn('apply');
   case 'apply';
      set(reorder.cancel,'UserData',tm.strings);
      set(reorder.apply,'Enable','off');
      set(reordergui,'UserData',reorder);
   case 'done';
      set(reorder.done,'UserData','done');
   case 'exit';
      set(reorder.done,'UserData','done');
      if strcmp(get(reorder.apply,'UserData'),'done')==1;
         delete(reordergui);
      end;
end;

if strcmp(selector,'init')==1;
   curr_ini = find_inisettings;
   if (iswinnt==1)&(iscompiled==1)&(curr_ini.loadguiicon==1);
      prog = ['bin\runwindow.exe ' fix_path([pwd '\bin\seticon.exe']) ' ' get(reordergui,'Name') ' ' fix_filepath([pwd '\icons\contents.ico'])];
      dos(prog);
      if (strcmp(curr_ini.pstoolsdir,'')==0)&(appexist([curr_ini.pstoolsdir 'pslist.exe'])==1);
         %
         % now we need to determine the pid
         %
         pid = getpid('seticon');
         set(reorder.icon,'UserData',pid);
      end;
   end;
   set(reordergui,'Visible','on');
   drawnow;
   if (iswinnt==1)&(iscompiled==1);
      drawnow;
      prog = ['bin\run_prog.exe ' fix_path([pwd '\bin\setfocus.exe']) ' ' get(reordergui,'Name') ' 3'];
      dos(prog);
      drawnow;
   end;
end;

if nargout==1;
   h = reordergui;
end;

if strcmp(selector,'exit')==0;
   set(reorder.thisfile,'UserData',tm);
end;

if thisexit==0;
   waitfor(reorder.done,'UserData','done');
end;

%
% end of reorder_fcn.m
%
