function [perm_shock,trans_shock,abort] = shockcomp(mm,Psi,alpha,beta,B,epsilon,init_val,trans_y,waitbar)

if nargin<9;
   waitbar = 0;
end;

%
% computes the parts of the permanent and transitory components that are
% explained by a certain shock
%

perm_shock = [];
trans_shock = [];
abort = '';

r = size(alpha,2);
shocks = inverse(B)*epsilon;
T = size(shocks,2);
if mm.deterselect(1,1)==1;
   %
   % unrestricted constant
   %
   mu = Psi(:,1:mm.d);
   con = mm.Z2(1:mm.d,:);
   mu = mu*con;
elseif mm.deterselect(1,2)==1;
   %
   % restricted constant
   %
   if r>0;
      if mm.d>0;
         mu = [Psi(:,1:mm.d) alpha*beta(size(beta,1),:)'];
         con = [mm.Z2(1:mm.d,:); mm.Z1(size(mm.Z1,1),:)];
      else;
         mu = alpha*beta(size(beta,1),:)';
         con = mm.Z1(size(mm.Z1,1),:);
      end;
      mu = mu*con;
   else;
      if mm.d>0;
         mu = Psi(:,1:mm.d);
         con = mm.Z2(1:mm.d,:);
         mu = mu*con;
      else;
         mu = zeros(mm.n,size(shocks,2));
      end;
   end;
elseif mm.deterselect(1,3)==1;
   %
   % linear trend
   %
   mu = Psi(:,1:mm.d);
   con = mm.Z2(1:mm.d,:);
   mu = mu*con;
elseif mm.deterselect(1,4)==1;
   %
   % restricted linear trend
   %
   mu_0 = Psi(:,1:mm.d);
   con = mm.Z2(1:mm.d,:);
   if r>0;
      mu_1 = alpha*beta(size(beta,1),:)';
      trend = mm.Z1(size(mm.Z1,1),:);
      mu = (mu_0*con)+(mu_1*trend);
   else;
      mu = (mu_0*con);
   end;
end;
mu = inverse(B)*mu;

trends = cumsum(shocks+mu,2);

%
% computing weights for initial values based on long-run variances
%

weights = zeros(mm.n,mm.n);
for i=1:mm.n;
   for j=1:mm.n;
      weights(i,j) = (mm.A(i,j)*mm.A(i,j))/(mm.A(i,:)*mm.A(i,:)');
   end;
end;
y_0 = init_val-epsilon(:,1);

%
% now we compute the permanent parts
%

for i=1:mm.n;
   perm_shock = [perm_shock;mm.A(:,i)*trends(i,:)+((weights(:,i) .* y_0)*ones(1,T))];
end;

%
% now we turn to the transitory part
%

if mm.p>=2;
   Phi = Psi(:,mm.d+1:mm.d+mm.n*(mm.p-1));
end;
if r>0;
   beta = beta(1:mm.n,:);
end;

if mm.p>=2;
   if r>0;
      Pi = [Phi alpha];
      if mm.p>2;
         Pi = [Pi;eye(mm.n*(mm.p-2)) zeros(mm.n*(mm.p-2),mm.n+r)];
      end;
      Pi = [Pi;beta'*Phi eye(r)+(beta'*alpha)];
   else;
      Pi = Phi;
      if mm.p>2;
         Pi = [Pi;eye(mm.n*(mm.p-2)) zeros(mm.n*(mm.p-2),mm.n)];
      end;
   end;
else;
   if r>0;
      Pi = [zeros(mm.n,mm.n) alpha;zeros(r,mm.n) eye(r)+beta'*alpha];
   else;
      %
      % the transitory component is 0 since we have a random walk
      %
      return;
   end;
end;
J_mat = zeros(mm.n,size(Pi,1));
J_mat(:,1:mm.n) = eye(mm.n);
K_mat = zeros(size(Pi,2),mm.n);
K_mat(1:mm.n,:) = eye(mm.n);
if r>0;
   K_mat(size(K_mat,1)-r+1:size(K_mat,1),:) = beta';
end;

num = 2;
c_crit = 1;
s(1).c = eye(mm.n);
s(1).sum_c = eye(mm.n);
C = mm.C(:,1:mm.n);
s(1).c_star = (eye(mm.n)-C)*B;
old_Pi = eye(size(Pi));
while (num<=100)&(c_crit>1.0e-010);
   old_Pi = old_Pi*Pi;
   s(num).c = J_mat*old_Pi*K_mat;
   s(num).sum_c = s(num-1).sum_c+s(num).c;
   s(num).c_star = (s(num).sum_c-C)*B;
   c_crit = norm(s(num).c_star,'fro');
   num = num+1;
end;

num = num-1;

%
% we can now compute transitory shock components
% using sum(j=0,infinity) c_star*shocks
%
%
% set up a waitbar
%

if waitbar==1;
   curr_ini = find_inisettings;
   realscrsz = get(0,'ScreenSize');
   input_var.title = ['Progress for ' int2str(mm.n*T) ' shock component values'];
   input_var.facecolor = curr_ini.progress_facecolor;
   input_var.startfacecolor = curr_ini.progress_startfacecolor;
   input_var.edgecolor = curr_ini.progress_edgecolor;
   input_var.bgcolor = curr_ini.progress_bgcolor;
   input_var.label = 'Run number:';
   input_var.stop = 0;
   input_var.clock = 1;
   input_var.name = 'Shock Components';
   mywait = progressdlg(0,input_var);
%   set(mywait,'Name','Shock Components');
   set(mywait,'Color',get(0,'defaultuicontrolbackgroundcolor'));
   drawnow;
end;

for i=1:mm.n;
   %
   % i is the shock
   %
   add_trans = zeros(mm.n,T);
   for j=1:T;
      if waitbar==1;
         if (i==1)&(j==1);
            drawnow;
            progressdlg([(1/(mm.n*T)) 1]);
         else;
            abort = get(mywait,'UserData');
            if strcmp(abort,'cancel')==1;
               break;
            else;
               progressdlg([((j+(T*(i-1)))/(mm.n*T)) j+(T*(i-1))]);
            end;
         end;
      end;
      %
      new_val = s(1).c_star(:,i)*shocks(i,j);
      %
      % sum backwards as far as possible
      %
      for j1=1:(min(j,num)-1);
         new_val = new_val+(s(j1+1).c_star(:,i)*shocks(i,j-j1));
      end;
      add_trans(:,j) = new_val;
   end;
   trans_shock = [trans_shock;add_trans];
end;

if (mm.q1+mm.q0)==0;
   %
   % try to make adjustments for trans_shock based on deviations from trans_y
   %
   check_mat = [];
   for i=1:mm.n;
      check_mat = [check_mat eye(mm.n)];
   end;
   diff_mat = trans_y-(check_mat*trans_shock);
   %
   % determine weights based on trans_shock
   %
   weight_base = check_mat*(trans_shock .* trans_shock);
   weight_base = check_mat'*weight_base;
   weight_numerator = trans_shock .* trans_shock;
   weight_mat = weight_numerator ./ weight_base;
   add_term = weight_mat .* (check_mat'*diff_mat);
   trans_shock = trans_shock+add_term;
   %
   % make a final mean adjustment
   %
   mean_trans = (1/T)*sum(trans_shock,2)*ones(1,T);
   trans_shock = trans_shock-(mean_trans);
   perm_shock = perm_shock+(mean_trans);
end;

if waitbar==1;
   set(mywait,'UserData','done');
   close(mywait);
   drawnow;
end;

%
% end of shockcomp.m
%
