%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                %
%          MatLab function for testing if the restrictions       %
%          on beta are identifying                               %
%                                                                %
%          Function: testident                                   %
%                                                                %
%          Input:                                                %
%                    modelsdir: text string with path to the     %
%                        H_i.rest files with restrictions        %
%                    modelfile: name of model                    %
%                    r: number of cointegration relations        %
%                    n: number of endogenous variables           %
%                    dcoint: indicator if constant or trend is   %
%                        in the cointegration space              %
%                    q1: number of exogenous I(1) variables      %
%                                                                %
%          Output:                                               %
%          		          status: rx1 0-1 vector with 1 meaning    %
%                           identified are 0 not                 %
%                                                                %
%          This version:        November 25, 2004                %
%          Written by: 	        Anders Warne                     %
%                               Copyright (c) 2001-2004          %
%                                                                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function status = testident(modelsdir,modelfile,r,n,dcoint,q1)

sivec = zeros(r,1);
H = [];

for i=1:r;
   file = strcat(modelsdir,'H_',num2str(i),'-',num2str(n),'x',num2str(r),'x',num2str(dcoint+q1),'-',modelfile,'.rest');
   if fileexist(file)==1;
      h = loaddata(file);
      H = [H h];
      sivec(i,1) = size(h,2);
   end;
end;

%
% Checking if identified
%
if isempty(H)==1
   status = zeros(r,1);
else;
   if r==1;
      myr = rank(H);
      if myr>=1;
         status = 1;
      else;
         status = 0;
      end;
   else;
      check = zeros(r-1,r-1);
      status = ones(r,1);
      for k=1:r
         icount = 0;
         Hk = selhmat(H,sivec,k);
         Hkort = null(Hk','r');
         matk1 = Hkort*Hkort';
         for i=1:r;
            if isequal(i,k)==0;
               jcount = 0;
               icount = icount + 1;
               Hi = selhmat(H,sivec,i);
               veci = randn(size(Hi,2),1);
               mati = Hi*veci;
               for j=1:i;
                  if isequal(j,k)==0;
                     jcount = jcount + 1;
                     Hj = selhmat(H,sivec,j);
                     vecj = randn(size(Hj,2),1);
                     matj = Hj*vecj;
                     hepp = mati'*matk1*matj;
                     check(icount,jcount) = hepp(1,1);
                     check(jcount,icount) = check(icount,jcount);
                  end;
               end;
            end;
         end;
         if abs(det(check))<1.0e-010;
            status(k,1) = 0;
         end;
      end;
   end;
end;

%
% end of testident.m
%